@@ -1,7 +1,7 @@
 // qtractorAudioClip.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -60,7 +60,8 @@ public:
 	void open();
 
 	// The main use method.
-	bool openAudioFile(const QString& sFilename, int iMode = qtractorAudioFile::Read);
+	bool openAudioFile(const QString& sFilename,
+		int iMode = qtractorAudioFile::Read);
 
 	// Sequence properties accessors.
 	qtractorAudioBuffer *buffer() const
