@@ -1,7 +1,7 @@
 // qtractorAudioPeak.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,6 +28,9 @@
 
 #include <QMutex>
 
+#include <QStringList>
+
+
 // Forward declarations.
 class qtractorAudioPeakThread;
 
@@ -50,6 +53,8 @@ public:
 	const QString& filename() const;
 	float timeStretch() const;
 
+	QString peakName() const;
+
 	// Peak cache properties accessors.
 	QString name() const;
 	unsigned short period();
@@ -80,13 +85,13 @@ public:
 	void write(float **ppAudioFrames, unsigned int iAudioFrames);
 	void closeWrite();
 
-	// Auto-delete property.
-	//bool isAutoRemove() const;
-
 	// Reference count methods.
 	void addRef();
 	void removeRef();
 
+	// Physical removal.
+	void remove();
+
 	// Sync thread state flags accessors.
 	void setWaitSync(bool bWaitSync);
 	bool isWaitSync() const;
@@ -203,8 +208,9 @@ public:
 	~qtractorAudioPeakFactory();
 
 	// The peak file factory-method.
+	static QString peakName(const QString& sFilename, float fTimeStretch);
 	qtractorAudioPeak *createPeak(const QString& sFilename, float fTimeStretch);
-	void removePeak(qtractorAudioPeakFile *pPeakFile);
+	void removePeak(qtractorAudioPeakFile *pPeakFile, bool bAborted);
 
 	// Auto-delete property.
 	void setAutoRemove(bool bAutoRemove);
@@ -216,6 +222,9 @@ public:
 	// Base sync method.
 	void sync(qtractorAudioPeakFile *pPeakFile = NULL);
 
+	// Cleanup method.
+	void cleanup();
+
 signals:
 
 	// Peak ready signal.
@@ -232,9 +241,11 @@ private:
 	// Auto-delete property.
 	bool m_bAutoRemove;
 
+	// The queue of discardable peak files.
+	QStringList m_files;
+
 	// The peak file creation detached thread.
 	qtractorAudioPeakThread *m_pPeakThread;
-
 };
 
 
