@@ -1,7 +1,7 @@
 // qtractorFiles.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -290,18 +290,18 @@ bool qtractorFiles::isFileSelected (void) const
 
 
 // Audio file addition convenience method.
-void qtractorFiles::addAudioFile ( const QString& sFilename, bool bAutoRemove )
+void qtractorFiles::addAudioFile ( const QString& sFilename )
 {
 	m_pTabWidget->setCurrentIndex(qtractorFiles::Audio);
-	m_pAudioListView->addFileItem(sFilename, bAutoRemove);
+	m_pAudioListView->addFileItem(sFilename);
 }
 
 
 // MIDI file addition convenience method.
-void qtractorFiles::addMidiFile ( const QString& sFilename, bool bAutoRemove )
+void qtractorFiles::addMidiFile ( const QString& sFilename )
 {
 	m_pTabWidget->setCurrentIndex(qtractorFiles::Midi);
-	m_pMidiListView->addFileItem(sFilename, bAutoRemove);
+	m_pMidiListView->addFileItem(sFilename);
 }
 
 
