@@ -240,8 +240,8 @@ void qtractorLadspaPlugin::setChannels ( unsigned short iChannels )
 		return;
 		
 	// Estimate the (new) number of instances...
-	unsigned short iOldInstances = instances();
-	unsigned short iInstances
+	const unsigned short iOldInstances = instances();
+	const unsigned short iInstances
 		= pType->instances(iChannels, list()->isMidi());
 	// Now see if instance count changed anyhow...
 	if (iInstances == iOldInstances)
@@ -252,7 +252,7 @@ void qtractorLadspaPlugin::setChannels ( unsigned short iChannels )
 		return;
 
 	// Gotta go for a while...
-	bool bActivated = isActivated();
+	const bool bActivated = isActivated();
 	setActivated(false);
 
 	// Set new instance number...
@@ -279,7 +279,7 @@ void qtractorLadspaPlugin::setChannels ( unsigned short iChannels )
 #endif
 
 	// We'll need output control (not dummy anymore) port indexes...
-	unsigned short iControlOuts = pType->controlOuts();
+	const unsigned short iControlOuts = pType->controlOuts();
 	// Allocate new instances...
 	m_phInstances = new LADSPA_Handle [iInstances];
 	for (unsigned short i = 0; i < iInstances; ++i) {
@@ -384,8 +384,8 @@ void qtractorLadspaPlugin::process (
 	const unsigned short iAudioIns  = audioIns();
 	const unsigned short iAudioOuts = audioOuts();
 
-	unsigned short iIChannel  = 0;
-	unsigned short iOChannel  = 0;
+	unsigned short iIChannel = 0;
+	unsigned short iOChannel = 0;
 	unsigned short i, j;
 
 	// For each plugin instance...
@@ -407,11 +407,13 @@ void qtractorLadspaPlugin::process (
 		}
 		// Make it run...
 		(*pLadspaDescriptor->run)(handle, nframes);
+	#if 0
 		// Wrap channels?...
 		if (iIChannel < iChannels - 1)
 			++iIChannel;
 		if (iOChannel < iChannels - 1)
 			++iOChannel;
+	#endif
 	}
 }
 
@@ -501,7 +503,7 @@ qtractorLadspaPluginParam::qtractorLadspaPluginParam (
 	setDefaultValue(fDefaultValue);
 
 	// Initialize port value...
-	reset();
+	// reset(); -- deferred to qtractorPlugin::addParam();
 }
 
 
