@@ -64,12 +64,14 @@ class qtractorLv2Worker;
 // LV2 External UI support.
 #include "lv2_external_ui.h"
 #endif
+#if QT_VERSION < 0x050000
+#undef CONFIG_LV2_UI_SHOW
+#endif
 #endif
 
 
 #ifdef CONFIG_LV2_STATE
 // LV2 State support.
-#include "lv2/lv2plug.in/ns/ext/atom/atom.h"
 #include "lv2/lv2plug.in/ns/ext/state/state.h"
 #endif
 
@@ -140,12 +142,12 @@ public:
 	static bool getTypes(qtractorPluginPath& path);
 
 #ifdef CONFIG_LV2_EVENT
-	unsigned short midiEventIns()  const { return m_iMidiEventIns;  }
-	unsigned short midiEventOuts() const { return m_iMidiEventOuts; }
+	unsigned short eventIns()   const { return m_iEventIns;   }
+	unsigned short eventOuts()  const { return m_iEventOuts;  }
 #endif
 #ifdef CONFIG_LV2_ATOM
-	unsigned short midiAtomIns()   const { return m_iMidiAtomIns;   }
-	unsigned short midiAtomOuts()  const { return m_iMidiAtomOuts;  }
+	unsigned short atomIns()    const { return m_iAtomIns;    }
+	unsigned short atomOuts()   const { return m_iAtomOuts;   }
 #endif
 
 	// Instance cached-deferred accesors.
@@ -160,12 +162,12 @@ protected:
 	LilvPlugin *m_lv2_plugin;
 
 #ifdef CONFIG_LV2_EVENT
-	unsigned short m_iMidiEventIns;
-	unsigned short m_iMidiEventOuts;
+	unsigned short m_iEventIns;
+	unsigned short m_iEventOuts;
 #endif
 #ifdef CONFIG_LV2_ATOM
-	unsigned short m_iMidiAtomIns;
-	unsigned short m_iMidiAtomOuts;
+	unsigned short m_iAtomIns;
+	unsigned short m_iAtomOuts;
 #endif
 };
 
@@ -270,8 +272,8 @@ public:
 #endif
 
 	// URID map/unmap helpers.
-	static uint32_t    lv2_urid_map(const char *uri);
-	static const char *lv2_urid_unmap(uint32_t id);
+	static LV2_URID    lv2_urid_map(const char *uri);
+	static const char *lv2_urid_unmap(LV2_URID id);
 
 #ifdef CONFIG_LV2_PROGRAMS
 
@@ -302,8 +304,12 @@ public:
 #endif
 #ifdef CONFIG_LV2_TIME
 	// Update LV2 Time from JACK transport position.
-	static void updateTime(
-		const jack_transport_state_t state, const jack_position_t *pPos);
+	static void updateTime(jack_client_t *pJackClient);
+	static void updateTimePost();
+#ifdef CONFIG_LV2_TIME_POSITION
+	// Make ready LV2 Time position.
+	void lv2_time_position_changed();
+#endif
 #endif
 
 private:
@@ -322,21 +328,21 @@ private:
 
 #ifdef CONFIG_LV2_EVENT
 	// List of LV2 Event/MIDI port indexes.
-	unsigned long *m_piMidiEventIns;
-	unsigned long *m_piMidiEventOuts;
+	unsigned long *m_piEventIns;
+	unsigned long *m_piEventOuts;
 #endif
 
 #ifdef CONFIG_LV2_ATOM
 
 	// List of LV2 Atom/MIDI port indexes and buffers.
-	unsigned long *m_piMidiAtomIns;
-	unsigned long *m_piMidiAtomOuts;
+	unsigned long *m_piAtomIns;
+	unsigned long *m_piAtomOuts;
 
 	LV2_Atom_Buffer **m_lv2_atom_buffer_ins;
-	LV2_Atom_Buffer **m_lv2_atom_port_ins;
-
 	LV2_Atom_Buffer **m_lv2_atom_buffer_outs;
-	LV2_Atom_Buffer **m_lv2_atom_port_outs;
+
+	unsigned long  m_lv2_atom_midi_port_in;
+	unsigned long  m_lv2_atom_midi_port_out;
 
 #endif
 
@@ -371,6 +377,8 @@ private:
 	SuilInstance  *m_suil_instance;
 	SuilWidget     m_lv2_ui_widget;
 
+	LV2UI_Handle   m_lv2_ui_handle;
+
 #ifdef CONFIG_LV2_ATOM
 
 	// LV2 Atom control (ring)buffers for UI updates.
@@ -395,16 +403,24 @@ private:
 #endif
 #endif
 
-#if QT_VERSION < 0x050000
 	// Our own Qt UI widget (native).
 	class EventFilter;
-	EventFilter *m_pQt4Filter;
-	QWidget     *m_pQt4Widget;
-#endif
+
+	EventFilter *m_pQtFilter;
+	QWidget     *m_pQtWidget;
 
 	// Changed UI params hash-queue.
 	QHash<unsigned long, float> m_ui_params;
 
+#ifdef CONFIG_LV2_UI_IDLE
+	// LV2 UI Idle extension data interface.
+	const LV2UI_Idle_Interface *m_lv2_ui_idle_interface;
+#endif
+#ifdef CONFIG_LV2_UI_SHOW
+	// LV2 UI Show extension data interface.
+	const LV2UI_Show_Interface *m_lv2_ui_show_interface;
+#endif
+
 #endif	// CONFIG_LV2_UI
 
 #ifdef CONFIG_LV2_STATE
@@ -428,12 +444,18 @@ private:
 
 #ifdef CONFIG_LV2_PRESETS
 	// LV2 Presets label-to-uri map.
-	QHash<QString, QString> m_lv2_presets;
+	QHash<QString, QString>    m_lv2_presets;
 #endif
 
 #ifdef CONFIG_LV2_TIME
 	// LV2 Time designated ports map.
 	QHash<unsigned long, int>  m_lv2_time_ports;
+#ifdef CONFIG_LV2_TIME_POSITION
+	// LV2 Time position port enabled index.
+	bool          m_lv2_time_position_enabled;
+	unsigned long m_lv2_time_position_port_in;
+	unsigned int  m_lv2_time_position_changed;
+#endif
 #endif
 
 #ifdef CONFIG_LV2_OPTIONS
@@ -460,9 +482,6 @@ public:
 	qtractorLv2PluginParam(qtractorLv2Plugin *pLv2Plugin,
 		unsigned long iIndex);
 
-	// Destructor.
-	~qtractorLv2PluginParam();
-
 	// Port range hints predicate methods.
 	bool isBoundedBelow() const;
 	bool isBoundedAbove() const;
