@@ -1,7 +1,7 @@
 // qtractorMessages.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
 
 #if !defined(WIN32)
 #include <unistd.h>
+#include <fcntl.h>
 #endif
 
 // The default maximum number of message lines.
@@ -143,12 +144,24 @@ void qtractorMessages::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
 void qtractorMessages::stdoutNotify ( int fd )
 {
 #if !defined(WIN32)
+	// Set non-blocking reads, if not already...
+	const int iFlags = ::fcntl(fd, F_GETFL, 0);
+	int iBlock = ((iFlags & O_NONBLOCK) == 0);
+	if (iBlock)
+		iBlock = ::fcntl(fd, F_SETFL, iFlags | O_NONBLOCK);
+	// Read as much as is available...
+	QString sTemp;
 	char achBuffer[1024];
-	int  cchBuffer = ::read(fd, achBuffer, sizeof(achBuffer) - 1);
-	if (cchBuffer > 0) {
-		achBuffer[cchBuffer] = (char) 0;
-		appendStdoutBuffer(achBuffer);
+	const int cchBuffer = sizeof(achBuffer) - 1;
+	int cchRead = ::read(fd, achBuffer, cchBuffer);
+	while (cchRead > 0) {
+		achBuffer[cchRead] = (char) 0;
+		sTemp.append(achBuffer);
+		cchRead = (iBlock ? 0 : ::read(fd, achBuffer, cchBuffer));
 	}
+	// Needs to be non-empty...
+	if (!sTemp.isEmpty())
+		appendStdoutBuffer(sTemp);
 #endif
 }
 
@@ -158,10 +171,10 @@ void qtractorMessages::appendStdoutBuffer ( const QString& s )
 {
 	m_sStdoutBuffer.append(s);
 
-	int iLength = m_sStdoutBuffer.lastIndexOf('\n') + 1;
+	const int iLength = m_sStdoutBuffer.lastIndexOf('\n');
 	if (iLength > 0) {
-		QString sTemp = m_sStdoutBuffer.left(iLength);
-		m_sStdoutBuffer.remove(0, iLength);
+		const QString& sTemp = m_sStdoutBuffer.left(iLength);
+		m_sStdoutBuffer.remove(0, iLength + 1);
 		QStringList list = sTemp.split('\n');
 		QStringListIterator iter(list);
 		while (iter.hasNext())
@@ -175,7 +188,7 @@ void qtractorMessages::flushStdoutBuffer (void)
 {
 	if (!m_sStdoutBuffer.isEmpty()) {
 		appendMessagesText(m_sStdoutBuffer);
-		m_sStdoutBuffer.truncate(0);
+		m_sStdoutBuffer.clear();
 	}
 }
 
@@ -183,7 +196,7 @@ void qtractorMessages::flushStdoutBuffer (void)
 // Stdout capture accessors.
 bool qtractorMessages::isCaptureEnabled (void) const
 {
-	return (bool) (m_pStdoutNotifier != NULL);
+	return (m_pStdoutNotifier != NULL);
 }
 
 void qtractorMessages::setCaptureEnabled ( bool bCapture )
@@ -205,10 +218,6 @@ void qtractorMessages::setCaptureEnabled ( bool bCapture )
 			::close(m_fdStdout[QTRACTOR_MESSAGES_FDREAD]);
 			m_fdStdout[QTRACTOR_MESSAGES_FDREAD]  = QTRACTOR_MESSAGES_FDNIL;
 		}
-		if (m_fdStdout[QTRACTOR_MESSAGES_FDREAD] != QTRACTOR_MESSAGES_FDNIL) {
-			::close(m_fdStdout[QTRACTOR_MESSAGES_FDREAD]);
-			m_fdStdout[QTRACTOR_MESSAGES_FDREAD]  = QTRACTOR_MESSAGES_FDNIL;
-		}
 	}
 	// Are we going to make up the capture?
 	if (bCapture && m_pStdoutNotifier == NULL && ::pipe(m_fdStdout) == 0) {
@@ -319,7 +328,8 @@ void qtractorMessages::appendMessages ( const QString& s )
 
 void qtractorMessages::appendMessagesColor ( const QString& s, const QString &c )
 {
-	QString sText = QTime::currentTime().toString("hh:mm:ss.zzz") + ' ' + s;
+	const QString& sText
+		= QTime::currentTime().toString("hh:mm:ss.zzz") + ' ' + s;
 	appendMessagesLine("<font color=\"" + c + "\">" + sText + "</font>");
 	appendMessagesLog(sText);
 }
