@@ -1,7 +1,7 @@
 // qtractorMidiBuffer.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -225,7 +225,7 @@ qtractorMidiManager::qtractorMidiManager (
 	m_queuedBuffer(iBufferSize),
 	m_postedBuffer(iBufferSize),
 	m_controllerBuffer(iBufferSize >> 2),
-	m_pBuffer(NULL), m_iBuffer(0),
+	m_pEventBuffer(NULL), m_iEventCount(0),
 #ifdef CONFIG_MIDI_PARSER
 	m_pMidiParser(NULL),
 #endif
@@ -241,7 +241,7 @@ qtractorMidiManager::qtractorMidiManager (
 {
 	const unsigned int MaxMidiEvents = (bufferSize() << 1);
 
-	m_pBuffer = new snd_seq_event_t [MaxMidiEvents];
+	m_pEventBuffer = new snd_seq_event_t [MaxMidiEvents];
 
 #ifdef CONFIG_MIDI_PARSER
 	if (snd_midi_event_new(c_iMaxMidiData, &m_pMidiParser) == 0)
@@ -324,8 +324,8 @@ qtractorMidiManager::~qtractorMidiManager (void)
 	}
 #endif
 
-	if (m_pBuffer)
-		delete [] m_pBuffer;
+	if (m_pEventBuffer)
+		delete [] m_pEventBuffer;
 }
 
 
@@ -353,41 +353,31 @@ bool qtractorMidiManager::direct ( snd_seq_event_t *pEvent )
 
 
 // Queued buffering.
-bool qtractorMidiManager::queued ( qtractorTimeScale *pTimeScale,
-	snd_seq_event_t *pEvent, unsigned long iTime, long iFrameStart )
+bool qtractorMidiManager::queued (
+	snd_seq_event_t *pEvent, unsigned long iTime, unsigned long iTimeOff )
 {
-	qtractorTimeScale::Cursor& cursor = pTimeScale->cursor();
-	qtractorTimeScale::Node *pNode = cursor.seekTick(iTime);
-	const unsigned long t0 = pNode->frameFromTick(iTime);
-	unsigned long t1 = (long(t0) < iFrameStart ? t0 : t0 - iFrameStart);
-
 	if (pEvent->type == SND_SEQ_EVENT_NOTE) {
 		snd_seq_event_t ev = *pEvent;
 		ev.type = SND_SEQ_EVENT_NOTEON;
-		if (!m_queuedBuffer.insert(&ev, t1))
+		if (!m_queuedBuffer.insert(&ev, iTime))
 			return false;
-		if (ev.data.note.duration > 0) {
-			iTime += (ev.data.note.duration - 1);
-			pNode = cursor.seekTick(iTime);
-			t1 += (pNode->frameFromTick(iTime) - t0);
-		}
 		ev.type = SND_SEQ_EVENT_NOTEOFF;
 		ev.data.note.velocity = 0;
 		ev.data.note.duration = 0;
-		return m_postedBuffer.insert(&ev, t1);
+		return m_postedBuffer.insert(&ev, iTimeOff);
 	}
 
 	if (pEvent->type == SND_SEQ_EVENT_NOTEOFF)
-		return m_postedBuffer.insert(pEvent, t1);
+		return m_postedBuffer.insert(pEvent, iTime);
 	else
-		return m_queuedBuffer.insert(pEvent, t1);
+		return m_queuedBuffer.insert(pEvent, iTime);
 }
 
 
 // Clears buffers for processing.
 void qtractorMidiManager::clear (void)
 {
-	m_iBuffer = 0;
+	m_iEventCount = 0;
 
 	// Reset event buffers...
 	for (unsigned short i = 0; i < 2; ++i) {
@@ -427,7 +417,7 @@ void qtractorMidiManager::process (
 
 	// Direct events...
 	while (pEv0) {
-		m_pBuffer[m_iBuffer++] = *pEv0;
+		m_pEventBuffer[m_iEventCount++] = *pEv0;
 		pEv0 = m_directBuffer.next();
 	}
 
@@ -436,16 +426,16 @@ void qtractorMidiManager::process (
 		|| (pEv2 && pEv2->time.tick < iTimeEnd)) {
 		while (pEv1 && pEv1->time.tick < iTimeEnd
 			&& ((pEv2 && pEv2->time.tick >= pEv1->time.tick) || !pEv2)) {
-			m_pBuffer[m_iBuffer] = *pEv1;
-			m_pBuffer[m_iBuffer++].time.tick
+			m_pEventBuffer[m_iEventCount] = *pEv1;
+			m_pEventBuffer[m_iEventCount++].time.tick
 				= (pEv1->time.tick > iTimeStart
 					? pEv1->time.tick - iTimeStart : 0);
 			pEv1 = m_queuedBuffer.next();
 		}
 		while (pEv2 && pEv2->time.tick < iTimeEnd
 			&& ((pEv1 && pEv1->time.tick > pEv2->time.tick) || !pEv1)) {
-			m_pBuffer[m_iBuffer] = *pEv2;
-			m_pBuffer[m_iBuffer++].time.tick
+			m_pEventBuffer[m_iEventCount] = *pEv2;
+			m_pEventBuffer[m_iEventCount++].time.tick
 				= (pEv2->time.tick > iTimeStart
 					? pEv2->time.tick - iTimeStart : 0);
 			pEv2 = m_postedBuffer.next();
@@ -453,8 +443,8 @@ void qtractorMidiManager::process (
 	}
 
 #ifdef CONFIG_DEBUG_0
-	for (unsigned int i = 0; i < m_iBuffer; ++i) {
-		snd_seq_event_t *pEv = &m_pBuffer[i];
+	for (unsigned int i = 0; i < m_iEventCount; ++i) {
+		snd_seq_event_t *pEv = &m_pEventBuffer[i];
 		// - show event for debug purposes...
 		const unsigned long iTime = iTimeStart + pEv->time.tick;
 		fprintf(stderr, "MIDI Seq %06lu 0x%02x", iTime, pEv->type);
@@ -496,8 +486,8 @@ void qtractorMidiManager::process (
 	#endif
 		unsigned char *pMidiData;
 		long iMidiData;
-		for (unsigned int i = 0; i < m_iBuffer; ++i) {
-			snd_seq_event_t *pEv = &m_pBuffer[i];
+		for (unsigned int i = 0; i < m_iEventCount; ++i) {
+			snd_seq_event_t *pEv = &m_pEventBuffer[i];
 			unsigned char midiData[c_iMaxMidiData];
 			pMidiData = &midiData[0];
 			iMidiData = sizeof(midiData);
@@ -524,7 +514,7 @@ void qtractorMidiManager::process (
 		#ifdef CONFIG_VST
 			VstMidiEvent *pVstMidiBuffer = m_ppVstMidiBuffers[m_iEventBuffer & 1];
 			VstMidiEvent *pVstMidiEvent = &pVstMidiBuffer[iVstMidiEvents];
-			if (iMidiData < long(pVstMidiEvent->midiData)) {
+			if (iMidiData < long(sizeof(pVstMidiEvent->midiData))) {
 				::memset(pVstMidiEvent, 0, sizeof(VstMidiEvent));
 				pVstMidiEvent->type = kVstMidiType;
 				pVstMidiEvent->byteSize = sizeof(VstMidiEvent);
@@ -766,7 +756,7 @@ void qtractorMidiManager::vst_events_swap (void)
 		long iMidiData = sizeof(pVstMidiEvent->midiData);
 	#ifdef CONFIG_MIDI_PARSER
 		if (m_pMidiParser) {
-			snd_seq_event_t *pEv = &m_pBuffer[iMidiEvents];
+			snd_seq_event_t *pEv = &m_pEventBuffer[iMidiEvents];
 		//	snd_seq_ev_clear(pEv);
 			iMidiData = snd_midi_event_encode(m_pMidiParser,
 				pMidiData, iMidiData, pEv);
@@ -785,7 +775,7 @@ void qtractorMidiManager::vst_events_swap (void)
 	#endif
 		++iMidiEvents;
 	}
-	m_iBuffer = iMidiEvents;
+	m_iEventCount = iMidiEvents;
 	swapEventBuffers();
 }
 
@@ -831,7 +821,7 @@ void qtractorMidiManager::lv2_events_swap (void)
 		#endif
 		#ifdef CONFIG_MIDI_PARSER
 			if (m_pMidiParser) {
-				snd_seq_event_t *pEv = &m_pBuffer[iMidiEvents];
+				snd_seq_event_t *pEv = &m_pEventBuffer[iMidiEvents];
 			//	snd_seq_ev_clear(pEv);
 				iMidiData = snd_midi_event_encode(m_pMidiParser,
 					pMidiData, iMidiData, pEv);
@@ -859,7 +849,7 @@ void qtractorMidiManager::lv2_events_swap (void)
 #ifdef CONFIG_VST
 	pVstEvents->numEvents = iMidiEvents;
 #endif
-	m_iBuffer = iMidiEvents;
+	m_iEventCount = iMidiEvents;
 	swapEventBuffers();
 }
 
@@ -905,7 +895,7 @@ void qtractorMidiManager::lv2_atom_buffer_swap (void)
 		#endif
 		#ifdef CONFIG_MIDI_PARSER
 			if (m_pMidiParser) {
-				snd_seq_event_t *pEv = &m_pBuffer[iMidiEvents];
+				snd_seq_event_t *pEv = &m_pEventBuffer[iMidiEvents];
 			//	snd_seq_ev_clear(pEv);
 				iMidiData = snd_midi_event_encode(m_pMidiParser,
 					pMidiData, iMidiData, pEv);
@@ -933,7 +923,7 @@ void qtractorMidiManager::lv2_atom_buffer_swap (void)
 #ifdef CONFIG_VST
 	pVstEvents->numEvents = iMidiEvents;
 #endif
-	m_iBuffer = iMidiEvents;
+	m_iEventCount = iMidiEvents;
 	swapEventBuffers();
 }
 
