@@ -1,7 +1,7 @@
 // qtractorMidiControl.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2009, gizzmo aka Mathias Krause. 
 
    This program is free software; you can redistribute it and/or
@@ -53,7 +53,7 @@ static inline float cbrtf2 ( float x )
 	u.i = (u.i / 3) + 710235478;
 	return u.f;
 #else
-	return cbrtf(x);
+	return ::cbrtf(x);
 #endif
 }
 
@@ -273,9 +273,12 @@ bool qtractorMidiControl::processEvent ( const qtractorCtlEvent& ctle )
 	}
 	else
 	if (key.isParamTrack()) {
-		unsigned short iParam = key.param() & TrackParamMask;
-		if (int(ctle.param()) >= iParam)
-			iTrack += int(ctle.param()) - iParam;
+		const unsigned short iKeyParam = key.param() & TrackParamMask;
+		const unsigned short iCtlParam = ctle.param();
+		if (iCtlParam >= iKeyParam)
+			iTrack += iCtlParam - iKeyParam;
+		else
+			return bResult;
 	}
 
 	qtractorSession *pSession = qtractorSession::getInstance();
@@ -376,8 +379,8 @@ void qtractorMidiControl::sendTrackController (
 				continue;
 			// Convert/normalize value...
 			const ControlType ctype = key.type();
+			const Scale scale(ctype);
 			unsigned short iValue = 0;
-			Scale scale(ctype);
 			switch (command) {
 			case TRACK_GAIN:
 				if (bCubic) fValue = ::cbrtf2(fValue);
@@ -414,9 +417,8 @@ void qtractorMidiControl::sendTrackController (
 	ControlType ctype, qtractorTrack *pTrack,
 	Command command, unsigned short iChannel, unsigned short iParam ) const
 {
-
+	const Scale scale(ctype);
 	unsigned short iValue = 0;
-	Scale scale(ctype);
 
 	switch (command) {
 	case TRACK_GAIN:
@@ -478,7 +480,7 @@ void qtractorMidiControl::sendController (
 void qtractorMidiControl::mapMidiObserver (
 	qtractorMidiControlObserver *pMidiObserver )
 {
-	MapKey key(
+	const MapKey key(
 		pMidiObserver->type(),
 		pMidiObserver->channel(),
 		pMidiObserver->param());
@@ -489,7 +491,7 @@ void qtractorMidiControl::mapMidiObserver (
 void qtractorMidiControl::unmapMidiObserver (
 	qtractorMidiControlObserver *pMidiObserver )
 {
-	MapKey key(
+	const MapKey key(
 		pMidiObserver->type(),
 		pMidiObserver->channel(),
 		pMidiObserver->param());
@@ -556,10 +558,10 @@ bool qtractorMidiControl::loadElement (
 		if (eItem.tagName() == "map") {
 			ControlType ctype
 				= typeFromText(eItem.attribute("type"));
-			unsigned short iChannel
+			const unsigned short iChannel
 				= keyFromText(eItem.attribute("channel"));
 			unsigned short iParam = 0;
-			bool bOldMap = (ctype == ControlType(0));
+			const bool bOldMap = (ctype == ControlType(0));
 			bool bOldTrackParam = false;
 			if (bOldMap) {
 				ctype  = qtractorMidiEvent::CONTROLLER;
