@@ -1,7 +1,7 @@
 // qtractorMidiControlForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -33,6 +33,36 @@
 #include <QUrl>
 
 
+//----------------------------------------------------------------------
+// qtractorMidiControlMapListItem -- Control Map item.
+//
+
+#include "qtractorConnect.h"
+
+class qtractorMidiControlMapListItem : public QTreeWidgetItem
+{
+public:
+
+	// Contructor.
+	qtractorMidiControlMapListItem() : QTreeWidgetItem() {}
+
+protected:
+
+	bool operator< ( const QTreeWidgetItem& other ) const
+	{
+		QTreeWidget *parent = QTreeWidgetItem::treeWidget();
+		if (parent == NULL)
+			return false;
+
+		const int col = parent->sortColumn();
+		if (col < 0)
+			return false;
+
+		return qtractorClientListView::lessThan(*this, other, col);
+	}
+};
+
+
 //----------------------------------------------------------------------
 // class qtractorMidiControlForm -- MIDI controller file manager form.
 //
@@ -195,10 +225,14 @@ void qtractorMidiControlForm::importSlot (void)
 	const QString  sExt("qtc");
 	const QString& sTitle  = tr("Import Controller Files") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("Controller files (*.%1)").arg(sExt);
-#if 0//QT_VERSION < 0x040400
+
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to open...
+	QFileDialog::Options options = 0;
+	if (pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	files = QFileDialog::getOpenFileNames(this,
-		sTitle, pOptions->sMidiControlDir, sFilter);
+		sTitle, pOptions->sMidiControlDir, sFilter, NULL, options);
 #else
 	// Construct open-files dialog...
 	QFileDialog fileDialog(this,
@@ -206,12 +240,15 @@ void qtractorMidiControlForm::importSlot (void)
 	// Set proper open-file modes...
 	fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
 	fileDialog.setFileMode(QFileDialog::ExistingFiles);
+	fileDialog.setHistory(pOptions->midiControlFiles);
 	fileDialog.setDefaultSuffix(sExt);
 	// Stuff sidebar...
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(pOptions->sMidiControlDir));
 	fileDialog.setSidebarUrls(urls);
+	if (pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		files = fileDialog.selectedFiles();
@@ -394,26 +431,40 @@ void qtractorMidiControlForm::exportSlot (void)
 	const QString  sExt("qtc");
 	const QString& sTitle  = tr("Export Controller File") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("Controller files (*.%1)").arg(sExt);
-#if 0//QT_VERSION < 0x040400
+
+	if (pOptions->midiControlFiles.isEmpty()) {
+		sPath =	QFileInfo(pOptions->sMidiControlDir,
+			tr("controller") + '.' + sExt).absoluteFilePath();
+	}
+	else sPath = pOptions->midiControlFiles.last();
+
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to open...
+	QFileDialog::Options options = 0;
+	if (pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sPath = QFileDialog::getSaveFileName(this,
-		sTitle, pOptions->sMidiControlDir, sFilter);
+		sTitle, sPath, sFilter, NULL, options);
 #else
 	// Construct open-files dialog...
-	QFileDialog fileDialog(this,
-		sTitle, pOptions->sMidiControlDir, sFilter);
+	QFileDialog fileDialog(this, sTitle, sPath, sFilter);
 	// Set proper open-file modes...
 	fileDialog.setAcceptMode(QFileDialog::AcceptSave);
 	fileDialog.setFileMode(QFileDialog::AnyFile);
+	fileDialog.setHistory(pOptions->midiControlFiles);
 	fileDialog.setDefaultSuffix(sExt);
 	// Stuff sidebar...
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(pOptions->sMidiControlDir));
 	fileDialog.setSidebarUrls(urls);
+	if (pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sPath = fileDialog.selectedFiles().first();
+	else
+		sPath.clear();
 #endif
 
 	if (sPath.isEmpty())
@@ -490,7 +541,7 @@ void qtractorMidiControlForm::reloadSlot (void)
 	pOptions->midiControlFiles.clear();
 
 	// Load each file in order...
-	int iItemCount = m_ui.FilesListView->topLevelItemCount();
+	const int iItemCount = m_ui.FilesListView->topLevelItemCount();
 	for (int iItem = 0; iItem < iItemCount; ++iItem) {
 		QTreeWidgetItem *pItem = m_ui.FilesListView->topLevelItem(iItem);
 		if (pItem) {
@@ -558,7 +609,8 @@ void qtractorMidiControlForm::stabilizeKeyChange (void)
 		&& (iChannel & qtractorMidiControl::TrackParam) == 0)
 		iParam |= qtractorMidiControl::TrackParam;
 
-	bool bMapped = pMidiControl->isChannelParamMapped(ctype, iChannel, iParam);
+	const bool bMapped
+		= pMidiControl->isChannelParamMapped(ctype, iChannel, iParam);
 
 	if (bMapped) {
 		QList<QTreeWidgetItem *> items
@@ -614,7 +666,8 @@ void qtractorMidiControlForm::stabilizeValueChange (void)
 		&& (iChannel & qtractorMidiControl::TrackParam) == 0)
 		iParam |= qtractorMidiControl::TrackParam;
 
-	bool bMapped = pMidiControl->isChannelParamMapped(ctype, iChannel, iParam);
+	const bool bMapped
+		= pMidiControl->isChannelParamMapped(ctype, iChannel, iParam);
 
 	if (bMapped) {
 		qtractorMidiControl::Command command
@@ -639,8 +692,8 @@ void qtractorMidiControlForm::stabilizeForm (void)
 
 	QTreeWidgetItem *pItem = m_ui.FilesListView->currentItem();
 	if (pItem) {
-		int iItem = m_ui.FilesListView->indexOfTopLevelItem(pItem);
-		int iItemCount = m_ui.FilesListView->topLevelItemCount();
+		const int iItem = m_ui.FilesListView->indexOfTopLevelItem(pItem);
+		const int iItemCount = m_ui.FilesListView->topLevelItemCount();
 		m_ui.RemovePushButton->setEnabled(true);
 		m_ui.MoveUpPushButton->setEnabled(iItem > 0);
 		m_ui.MoveDownPushButton->setEnabled(iItem < iItemCount - 1);
@@ -655,12 +708,14 @@ void qtractorMidiControlForm::stabilizeForm (void)
 		++m_iUpdating;
 		m_pControlTypeGroup->setControlType(
 			qtractorMidiControl::typeFromName(pItem->text(0)));
-		m_pControlTypeGroup->setControlParam(pItem->text(2).toInt());
+		m_pControlTypeGroup->setControlParam( // remove non-digits tail...
+			pItem->text(2).remove(QRegExp("[\\D]+.*$")).toUShort());
 		m_ui.ChannelComboBox->setCurrentIndex(
 			m_ui.ChannelComboBox->findText(pItem->text(1)));
-		const QString& sText = pItem->text(3);
+		QString sText = pItem->text(3);
 		m_ui.TrackCheckBox->setChecked(sText[0] == '+');
-		m_ui.TrackSpinBox->setValue(sText.toInt());
+		m_ui.TrackSpinBox->setValue( // remove non-digits any...
+			sText.remove(QRegExp("[\\D]*")).toInt());
 		m_ui.CommandComboBox->setCurrentIndex(
 			m_ui.CommandComboBox->findText(pItem->text(4)));
 		m_ui.FeedbackCheckBox->setChecked(pItem->text(5) == tr("Yes"));
@@ -732,10 +787,11 @@ void qtractorMidiControlForm::refreshControlMap (void)
 	const QIcon	iconControlType(":/images/itemProperty.png");
 	const QIcon	iconParam(":/images/itemControllers.png");
 	const QIcon	iconCommand(":/images/itemChannel.png");
+	qtractorMidiControlMapListItem *pItem;
 	for ( ; it != it_end; ++it) {
 		const qtractorMidiControl::MapKey& key = it.key();
 		const qtractorMidiControl::MapVal& val = it.value();
-		QTreeWidgetItem *pItem = new QTreeWidgetItem();
+		pItem = new qtractorMidiControlMapListItem();
 		pItem->setIcon(0, iconControlType);
 		pItem->setText(0, qtractorMidiControl::nameFromType(key.type()));
 		pItem->setText(1, textFromChannel(key.channel()));
