@@ -137,7 +137,7 @@ qtractorMidiEditEvent::qtractorMidiEditEvent (
 	m_pHzoomIn->setIcon(QIcon(":/images/viewZoomIn.png"));
 	m_pHzoomReset->setIcon(QIcon(":/images/viewZoomTool.png"));
 
-	int iScrollBarExtent
+	const int iScrollBarExtent
 		= qtractorScrollView::style()->pixelMetric(QStyle::PM_ScrollBarExtent);
 	m_pHzoomReset->setFixedWidth(iScrollBarExtent);
 	m_pHzoomIn->setFixedWidth(iScrollBarExtent);
@@ -419,8 +419,9 @@ void qtractorMidiEditEvent::updatePixmap ( int cx, int /*cy*/ )
 			else
 				y = y0 - (y0 * pEvent->value()) / 128;
 			pNode = cursor.seekTick(t1);
-			x = pNode->pixelFromTick(t1) - x0 - cx;
-			int w1 = pNode->pixelFromTick(t2) - x0 - cx - x;
+			x = pNode->pixelFromTick(t1) - dx;
+			pNode = cursor.seekTick(t2);
+			int w1 = pNode->pixelFromTick(t2) - dx - x;
 			if (w1 < 5 || !m_pEditor->isNoteDuration())
 				w1 = 5;
 			if (m_eventType == qtractorMidiEvent::NOTEON ||
@@ -503,8 +504,9 @@ void qtractorMidiEditEvent::drawContents ( QPainter *pPainter, const QRect& rect
 	m_pEditor->paintDragState(this, pPainter);
 
 	// Draw special play-head line...
-	int cx = qtractorScrollView::contentsX();
-	int x  = m_pEditor->playHeadX() - cx;
+	const int cx = qtractorScrollView::contentsX();
+
+	int x = m_pEditor->playHeadX() - cx;
 	if (x >= rect.left() && x <= rect.right()) {
 		pPainter->setPen(Qt::red);
 		pPainter->drawLine(x, rect.top(), x, rect.bottom());
@@ -569,7 +571,7 @@ void qtractorMidiEditEvent::mousePressEvent ( QMouseEvent *pMouseEvent )
 	const QPoint& pos
 		= qtractorScrollView::viewportToContents(pMouseEvent->pos());
 	qtractorTimeScale *pTimeScale = m_pEditor->timeScale();
-	unsigned long iFrame = pTimeScale->frameSnap(m_pEditor->offset()
+	const unsigned long iFrame = pTimeScale->frameSnap(m_pEditor->offset()
 		+ pTimeScale->frameFromPixel(pos.x() > 0 ? pos.x() : 0));
 
 	switch (pMouseEvent->button()) {
@@ -596,7 +598,6 @@ void qtractorMidiEditEvent::mousePressEvent ( QMouseEvent *pMouseEvent )
 		return;
 	}
 
-
 	// Remember what and where we'll be dragging/selecting...
 	m_pEditor->dragMoveStart(this, pos, pMouseEvent->modifiers());
 }
