@@ -1,7 +1,7 @@
 // qtractorMidiEditView.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -71,7 +71,7 @@ qtractorMidiEditView::qtractorMidiEditView (
 	m_pVzoomOut->setToolTip(tr("Zoom out (vertical)"));
 	m_pVzoomReset->setToolTip(tr("Zoom reset (vertical)"));
 
-	int iScrollBarExtent
+	const int iScrollBarExtent
 		= qtractorScrollView::style()->pixelMetric(QStyle::PM_ScrollBarExtent);
 	m_pVzoomReset->setFixedHeight(iScrollBarExtent);
 	m_pVzoomOut->setFixedHeight(iScrollBarExtent);
@@ -145,9 +145,12 @@ void qtractorMidiEditView::updateContentsWidth ( int iContentsWidth )
 	if (pTimeScale) {
 		qtractorMidiSequence *pSeq = m_pEditor->sequence();
 		if (pSeq) {
-			unsigned long t0 = pTimeScale->tickFromFrame(m_pEditor->offset());
-			int x0 = pTimeScale->pixelFromFrame(m_pEditor->offset());
-			int w0 = pTimeScale->pixelFromTick(t0 + pSeq->duration()) - x0;
+			const unsigned long t0
+				= pTimeScale->tickFromFrame(m_pEditor->offset());
+			const int x0
+				= pTimeScale->pixelFromFrame(m_pEditor->offset());
+			const int w0
+				= pTimeScale->pixelFromTick(t0 + pSeq->duration()) - x0;
 			if (iContentsWidth < w0)
 				iContentsWidth = w0;
 		}
@@ -214,7 +217,7 @@ void qtractorMidiEditView::resizeEvent ( QResizeEvent *pResizeEvent )
 	// Scrollbar/tools layout management.
 	const QSize& size = qtractorScrollView::size();
 	QScrollBar *pVScrollBar = qtractorScrollView::verticalScrollBar();
-	int w = pVScrollBar->width(); 
+	const int w = pVScrollBar->width();
 
 	updateContents();
 
@@ -381,8 +384,9 @@ void qtractorMidiEditView::updatePixmap ( int cx, int cy )
 			y = ch - h1 * (pEvent->note() + 1);
 			if (y + h1 >= 0 && y < h) {
 				pNode = cursor.seekTick(t1);
-				x = pNode->pixelFromTick(t1) - x0 - cx;
-				int w1 = pNode->pixelFromTick(t2) - x0 - cx - x;
+				x = pNode->pixelFromTick(t1) - dx;
+				pNode = cursor.seekTick(t2);
+				int w1 = pNode->pixelFromTick(t2) - dx - x;
 				if (w1 < 5) w1 = 5;
 				if (m_pEditor->isNoteColor()) {
 					hue = (128 - int(pEvent->note())) << 4;
@@ -456,8 +460,9 @@ void qtractorMidiEditView::drawContents ( QPainter *pPainter, const QRect& rect
 	m_pEditor->paintDragState(this, pPainter);
 
 	// Draw special play-head line...
-	int cx = qtractorScrollView::contentsX();
-	int x  = m_pEditor->playHeadX() - cx;
+	const int cx = qtractorScrollView::contentsX();
+
+	int x = m_pEditor->playHeadX() - cx;
 	if (x >= rect.left() && x <= rect.right()) {
 		pPainter->setPen(Qt::red);
 		pPainter->drawLine(x, rect.top(), x, rect.bottom());
@@ -523,14 +528,14 @@ void qtractorMidiEditView::mousePressEvent ( QMouseEvent *pMouseEvent )
 		return;
 
 	// Which mouse state?
-	bool bModifier = (pMouseEvent->modifiers() &
-		(Qt::ShiftModifier | Qt::ControlModifier));
+	bool bModifier = (pMouseEvent->modifiers()
+		& (Qt::ShiftModifier | Qt::ControlModifier));
 
 	// Maybe start the drag-move-selection dance?
 	const QPoint& pos
 		= qtractorScrollView::viewportToContents(pMouseEvent->pos());
 	qtractorTimeScale *pTimeScale = m_pEditor->timeScale();
-	unsigned long iFrame = pTimeScale->frameSnap(m_pEditor->offset()
+	const unsigned long iFrame = pTimeScale->frameSnap(m_pEditor->offset()
 		+ pTimeScale->frameFromPixel(pos.x() > 0 ? pos.x() : 0));
 
 	// We'll need options somehow...
@@ -620,4 +625,3 @@ bool qtractorMidiEditView::eventFilter ( QObject *pObject, QEvent *pEvent )
 
 
 // end of qtractorMidiEditView.cpp
-
