@@ -411,6 +411,9 @@ protected:
 	// Zoom factor constants.
 	enum { ZoomMin = 10, ZoomBase = 100, ZoomMax = 1000, ZoomStep = 10 };
 
+	// Zoom step evaluator.
+	int zoomStep() const;
+
 	// Common zoom factor settlers.
 	void horizontalZoomStep(int iZoomStep);
 	void verticalZoomStep(int iZoomStep);
@@ -476,16 +479,16 @@ protected:
 	// Finalize the event drag-move.
 	void executeDragMove(qtractorScrollView *pScrollView, const QPoint& pos);
 
-	// Drag-rescale current selection.
-	void updateDragRescale(qtractorScrollView *pScrollView, const QPoint& pos);
-	// Finalize the event drag-rescale.
-	void executeDragRescale(qtractorScrollView *pScrollView, const QPoint& pos);
-
 	// Drag-resize current selection (also editing).
 	void updateDragResize(qtractorScrollView *pScrollView, const QPoint& pos);
 	// Finalize the event drag-resize (also editing).
 	void executeDragResize(qtractorScrollView *pScrollView, const QPoint& pos);
 
+	// Drag-rescale current selection.
+	void updateDragRescale(qtractorScrollView *pScrollView, const QPoint& pos);
+	// Finalize the event drag-rescale.
+	void executeDragRescale(qtractorScrollView *pScrollView, const QPoint& pos);
+
 	// Finalize the event drag-paste.
 	void executeDragPaste(qtractorScrollView *pScrollView, const QPoint& pos);
 
