@@ -1,7 +1,7 @@
 // qtractorMidiEngine.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -145,8 +145,6 @@ public:
 	// The delta-time/frame accessors.
 	long timeStart() const;
 
-	long frameStart() const;
-
 	// Special track-immediate methods.
 	void trackMute(qtractorTrack *pTrack, bool bMute);
 
@@ -305,12 +303,13 @@ private:
 
 	// The number of times we check for time drift.
 	unsigned int m_iDriftCheck;
+	unsigned int m_iDriftCount;
 
 	// The delta-time/frame when playback started .
 	long m_iTimeStart;
 	long m_iTimeDrift;
-
 	long m_iFrameStart;
+	long m_iFrameDrift;
 	long m_iFrameTime;
 
 	// The assigned control buses.
