@@ -1,7 +1,7 @@
 // qtractorOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -122,9 +122,18 @@ qtractorOptionsForm::qtractorOptionsForm (
 	m_ui.MidiCaptureFormatComboBox->addItem(tr("SMF Format 1"));
 
 	// Populate the MIDI capture quantize combo-box.
-	QStringList items = qtractorTimeScale::snapItems(0);
+	const QIcon snapIcon(":/images/itemBeat.png");
+	const QStringList& snapItems = qtractorTimeScale::snapItems(0);
+	QStringListIterator snapIter(snapItems);
 	m_ui.MidiCaptureQuantizeComboBox->clear();
-	m_ui.MidiCaptureQuantizeComboBox->insertItems(0, items);
+	m_ui.MidiCaptureQuantizeComboBox->setIconSize(QSize(8, 16));
+//	snapIter.toFront();
+	if (snapIter.hasNext())
+		m_ui.MidiCaptureQuantizeComboBox->addItem(
+			QIcon(":/images/itemNone.png"), snapIter.next());
+	while (snapIter.hasNext())
+		m_ui.MidiCaptureQuantizeComboBox->addItem(snapIcon, snapIter.next());
+//	m_ui.MidiCaptureQuantizeComboBox->insertItems(0, items);
 
 	// Populate the MMC device combo-box.
 	m_ui.MidiMmcDeviceComboBox->clear();
@@ -153,6 +162,8 @@ qtractorOptionsForm::qtractorOptionsForm (
 #ifdef CONFIG_LV2
 	m_ui.PluginTypeComboBox->addItem(
 		qtractorPluginType::textFromHint(qtractorPluginType::Lv2));
+#else
+	m_ui.Lv2DynManifestCheckBox->hide();
 #endif
 
 #ifndef CONFIG_LV2_PRESETS
@@ -399,6 +410,12 @@ qtractorOptionsForm::qtractorOptionsForm (
 	QObject::connect(m_ui.DummyVstScanCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(changed()));
+	QObject::connect(m_ui.Lv2DynManifestCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(changed()));
+	QObject::connect(m_ui.SaveCurve14bitCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(changed()));
 	QObject::connect(m_ui.MessagesFontPushButton,
 		SIGNAL(clicked()),
 		SLOT(chooseMessagesFont()));
@@ -417,6 +434,12 @@ qtractorOptionsForm::qtractorOptionsForm (
 	QObject::connect(m_ui.MessagesLogPathToolButton,
 		SIGNAL(clicked()),
 		SLOT(chooseMessagesLogPath()));
+	QObject::connect(m_ui.SyncViewHoldCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(changed()));
+	QObject::connect(m_ui.UseNativeDialogsCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(changed()));
 	QObject::connect(m_ui.DialogButtonBox,
 		SIGNAL(accepted()),
 		SLOT(accept()));
@@ -553,6 +576,12 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 	m_ui.MessagesLimitCheckBox->setChecked(m_pOptions->bMessagesLimit);
 	m_ui.MessagesLimitLinesSpinBox->setValue(m_pOptions->iMessagesLimitLines);
 
+	// Transport display preferences...
+	m_ui.SyncViewHoldCheckBox->setChecked(m_pOptions->bSyncViewHold);
+
+	// Dialogs preferences...
+	m_ui.UseNativeDialogsCheckBox->setChecked(m_pOptions->bUseNativeDialogs);
+
 	// Logging options...
 	m_ui.MessagesLogCheckBox->setChecked(m_pOptions->bMessagesLog);
 	m_ui.MessagesLogPathComboBox->setEditText(m_pOptions->sMessagesLogPath);
@@ -596,6 +625,8 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 	m_ui.AudioOutputAutoConnectCheckBox->setChecked(m_pOptions->bAudioOutputAutoConnect);
 	m_ui.OpenEditorCheckBox->setChecked(m_pOptions->bOpenEditor);
 	m_ui.DummyVstScanCheckBox->setChecked(m_pOptions->bDummyVstScan);
+	m_ui.Lv2DynManifestCheckBox->setChecked(m_pOptions->bLv2DynManifest);
+	m_ui.SaveCurve14bitCheckBox->setChecked(m_pOptions->bSaveCurve14bit);
 
 	int iPluginType = m_pOptions->iPluginType - 1;
 	if (iPluginType < 0)
@@ -696,6 +727,8 @@ void qtractorOptionsForm::accept (void)
 		m_pOptions->bAudioOutputAutoConnect = m_ui.AudioOutputAutoConnectCheckBox->isChecked();
 		m_pOptions->bOpenEditor          = m_ui.OpenEditorCheckBox->isChecked();
 		m_pOptions->bDummyVstScan        = m_ui.DummyVstScanCheckBox->isChecked();
+		m_pOptions->bLv2DynManifest      = m_ui.Lv2DynManifestCheckBox->isChecked();
+		m_pOptions->bSaveCurve14bit      = m_ui.SaveCurve14bitCheckBox->isChecked();
 		// Messages options...
 		m_pOptions->sMessagesFont        = m_ui.MessagesFontTextLabel->font().toString();
 		m_pOptions->bMessagesLimit       = m_ui.MessagesLimitCheckBox->isChecked();
@@ -718,6 +751,11 @@ void qtractorOptionsForm::accept (void)
 			qtractorAudioMeter::setColor(iColor, m_audioMeterColors[iColor]);
 		for (iColor = 0; iColor < MidiMeterColors; ++iColor)
 			qtractorMidiMeter::setColor(iColor, m_midiMeterColors[iColor]);
+		// Transport display preferences...
+		m_pOptions->bSyncViewHold = m_ui.SyncViewHoldCheckBox->isChecked();
+		// Dialogs preferences...
+		m_pOptions->bUseNativeDialogs = m_ui.UseNativeDialogsCheckBox->isChecked();
+		m_pOptions->bDontUseNativeDialogs = !m_pOptions->bUseNativeDialogs;
 		// Reset dirty flag.
 		m_iDirtyCount = 0;
 	}
@@ -879,7 +917,9 @@ void qtractorOptionsForm::changeMidiMeterColor ( const QString& sColor )
 void qtractorOptionsForm::chooseAudioMeterColor (void)
 {
 	const QColor& color = QColorDialog::getColor(
-		QColor(m_ui.AudioMeterColorLineEdit->text()), this);
+		QColor(m_ui.AudioMeterColorLineEdit->text()), this,
+		tr("Audio Meter Color") + " - " QTRACTOR_TITLE);
+
 	if (color.isValid())
 		m_ui.AudioMeterColorLineEdit->setText(color.name());
 }
@@ -889,7 +929,9 @@ void qtractorOptionsForm::chooseAudioMeterColor (void)
 void qtractorOptionsForm::chooseMidiMeterColor (void)
 {
 	const QColor& color = QColorDialog::getColor(
-		QColor(m_ui.MidiMeterColorLineEdit->text()), this);
+		QColor(m_ui.MidiMeterColorLineEdit->text()), this,
+		tr("MIDI Meter Color") + " - " QTRACTOR_TITLE);
+
 	if (color.isValid())
 		m_ui.MidiMeterColorLineEdit->setText(color.name());
 }
@@ -931,9 +973,7 @@ void qtractorOptionsForm::choosePluginType ( int iPluginType )
 	qtractorPluginType::Hint typeHint
 		= qtractorPluginType::hintFromText(
 			m_ui.PluginTypeComboBox->itemText(iPluginType));
-#ifdef CONFIG_LV2_PRESETS
-    bool bLv2Enabled = false;
-#endif
+
 	switch (typeHint) {
 	case qtractorPluginType::Ladspa:
 		paths = m_ladspaPaths;
@@ -946,10 +986,7 @@ void qtractorOptionsForm::choosePluginType ( int iPluginType )
 		break;
 	case qtractorPluginType::Lv2:
 		paths = m_lv2Paths;
-    #ifdef CONFIG_LV2_PRESETS
-        bLv2Enabled = true;
-    #endif
-		break;
+		// Fall thru...
 	default:
 		break;
 	}
@@ -959,12 +996,6 @@ void qtractorOptionsForm::choosePluginType ( int iPluginType )
 	while (iter.hasNext())
 		m_ui.PluginPathListWidget->addItem(iter.next());
 
-#ifdef CONFIG_LV2_PRESETS
-	m_ui.Lv2PresetDirLabel->setEnabled(bLv2Enabled);
-	m_ui.Lv2PresetDirComboBox->setEnabled(bLv2Enabled);
-	m_ui.Lv2PresetDirToolButton->setEnabled(bLv2Enabled);
-#endif
-
 	selectPluginPath();
 	stabilizeForm();
 }
@@ -986,8 +1017,11 @@ void qtractorOptionsForm::choosePluginPath (void)
 	const QString& sTitle = tr("Plug-in Directory") + " - " QTRACTOR_TITLE;
 #if 1//QT_VERSION < 0x040400
 	// Ask for the directory...
+	QFileDialog::Options options = QFileDialog::ShowDirsOnly;
+	if (m_pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
     sPluginPath = QFileDialog::getExistingDirectory(this,
-		sTitle, m_ui.PluginPathComboBox->currentText());
+		sTitle, m_ui.PluginPathComboBox->currentText(), options);
 #else
 	// Construct open-directory dialog...
 	QFileDialog fileDialog(this,
@@ -999,6 +1033,8 @@ void qtractorOptionsForm::choosePluginPath (void)
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(m_pOptions->sSessionDir));
 	fileDialog.setSidebarUrls(urls);
+	if (m_pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sPluginPath = fileDialog.selectedFiles().first();
@@ -1209,8 +1245,11 @@ void qtractorOptionsForm::chooseLv2PresetDir (void)
 	const QString& sTitle = tr("LV2 Presets Directory") + " - " QTRACTOR_TITLE;
 #if 1// QT_VERSION < 0x040400
 	// Ask for the directory...
+	QFileDialog::Options options = QFileDialog::ShowDirsOnly;
+	if (m_pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sLv2PresetDir = QFileDialog::getExistingDirectory(this,
-		sTitle, sLv2PresetDir);
+		sTitle, sLv2PresetDir, options);
 #else
 	// Construct open-directory dialog...
 	QFileDialog fileDialog(this,
@@ -1222,6 +1261,8 @@ void qtractorOptionsForm::chooseLv2PresetDir (void)
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(m_pOptions->sLv2PresetDir));
 	fileDialog.setSidebarUrls(urls);
+	if (m_pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sLv2PresetDir = fileDialog.selectedFiles().first();
@@ -1259,10 +1300,13 @@ void qtractorOptionsForm::chooseMessagesLogPath (void)
 	const QString  sExt("log");
 	const QString& sTitle  = tr("Messages Log") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("Log files (*.%1)").arg(sExt); 
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to open...
+	QFileDialog::Options options = 0;
+	if (m_pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sFilename = QFileDialog::getSaveFileName(this,
-		sTitle, m_ui.MessagesLogPathComboBox->currentText(), sFilter);
+		sTitle, m_ui.MessagesLogPathComboBox->currentText(), sFilter, NULL, options);
 #else
 	// Construct open-file dialog...
 	QFileDialog fileDialog(this,
@@ -1271,6 +1315,8 @@ void qtractorOptionsForm::chooseMessagesLogPath (void)
 	fileDialog.setAcceptMode(QFileDialog::AcceptSave);
 	fileDialog.setFileMode(QFileDialog::AnyFile);
 	fileDialog.setDefaultSuffix(sExt);
+	if (m_pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sFilename = fileDialog.selectedFiles().first();
@@ -1292,10 +1338,13 @@ void qtractorOptionsForm::chooseSessionTemplatePath (void)
 	const QString  sExt("qtt");
 	const QString& sTitle  = tr("Session Template") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("Session template files (*.qtr *.qts *.%1)").arg(sExt); 
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to open...
+	QFileDialog::Options options = 0;
+	if (m_pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sFilename = QFileDialog::getOpenFileName(this,
-		sTitle, m_ui.SessionTemplatePathComboBox->currentText(), sFilter);
+		sTitle, m_ui.SessionTemplatePathComboBox->currentText(), sFilter, NULL, options);
 #else
 	// Construct open-files dialog...
 	QFileDialog fileDialog(this,
@@ -1308,6 +1357,8 @@ void qtractorOptionsForm::chooseSessionTemplatePath (void)
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(m_pOptions->sSessionDir));
 	fileDialog.setSidebarUrls(urls);
+	if (m_pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sFilename = fileDialog.selectedFiles().first();
@@ -1439,10 +1490,13 @@ QString qtractorOptionsForm::getOpenAudioFileName (
 {
 	QString sAudioFile;
 
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to open...
+	QFileDialog::Options options = 0;
+	if (m_pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sAudioFile = QFileDialog::getOpenFileName(this,
-		sTitle, sFilename, qtractorAudioFileFactory::filters());
+		sTitle, sFilename, qtractorAudioFileFactory::filters(), NULL, options);
 #else
 	// Construct open-file dialog...
 	QFileDialog fileDialog(this,
@@ -1456,6 +1510,8 @@ QString qtractorOptionsForm::getOpenAudioFileName (
 	urls.append(QUrl::fromLocalFile(m_pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(m_pOptions->sAudioDir));
 	fileDialog.setSidebarUrls(urls);
+	if (m_pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sAudioFile = fileDialog.selectedFiles().first();
