@@ -34,6 +34,8 @@
 #include "qtractorDocument.h"
 #include "qtractorCurveFile.h"
 
+#include "qtractorMessageList.h"
+
 #ifdef CONFIG_LADSPA
 #include "qtractorLadspaPlugin.h"
 #endif
@@ -286,7 +288,7 @@ void qtractorPluginFile::close (void)
 		(*pfnFini)();
 #endif
 
-	if (m_bAutoUnload) QLibrary::unload();
+	QLibrary::unload();
 }
 
 
@@ -507,12 +509,21 @@ unsigned short qtractorPluginType::instances (
 		if (bMidi && m_iMidiOuts > 0)
 			iInstances = 1;
 		else
+	#if 0
 		if (iChannels >= m_iAudioIns && m_iAudioOuts > 0)
 			iInstances = (m_iAudioOuts >= iChannels ? 1 : iChannels);
 		else
 		if (m_iAudioOuts >= iChannels)
 			iInstances = (iChannels >= m_iAudioIns ? iChannels : 1);
 		else
+	#else
+		if (m_iAudioOuts >= iChannels || m_iAudioIns >= iChannels)
+			iInstances = 1;
+		else
+		if (m_iAudioOuts > 0)
+			iInstances = (iChannels / m_iAudioOuts);
+		else
+	#endif
 		if (bMidi && m_iMidiIns > 0)
 			iInstances = 1;
 	}
@@ -524,65 +535,49 @@ unsigned short qtractorPluginType::instances (
 qtractorPluginType::Hint qtractorPluginType::hintFromText (
 	const QString& sText )
 {
-#ifdef CONFIG_LADSPA
 	if (sText == "LADSPA")
 		return Ladspa;
 	else
-#endif
-#ifdef CONFIG_DSSI
 	if (sText == "DSSI")
 		return Dssi;
 	else
-#endif
-#ifdef CONFIG_VST
 	if (sText == "VST")
 		return Vst;
 	else
-#endif
-#ifdef CONFIG_LV2
 	if (sText == "LV2")
 		return Lv2;
 	else
-#endif
 	if (sText == "Insert")
 		return Insert;
 	else
 	if (sText == "AuxSend")
 		return AuxSend;
 	else
-	return Any;
+		return Any;
 }
 
 QString qtractorPluginType::textFromHint (
 	qtractorPluginType::Hint typeHint )
 {
-#ifdef CONFIG_LADSPA
 	if (typeHint == Ladspa)
 		return "LADSPA";
 	else
-#endif
-#ifdef CONFIG_DSSI
 	if (typeHint == Dssi)
 		return "DSSI";
 	else
-#endif
-#ifdef CONFIG_VST
 	if (typeHint == Vst)
 		return "VST";
 	else
-#endif
-#ifdef CONFIG_LV2
 	if (typeHint == Lv2)
 		return "LV2";
 	else
-#endif
 	if (typeHint == Insert)
 		return "Insert";
 	else
 	if (typeHint == AuxSend)
 		return "AuxSend";
 	else
-	return QObject::tr("(Any)");
+		return QObject::tr("(Any)");
 }
 
 
@@ -653,15 +648,25 @@ const QString& qtractorDummyPluginType::aboutText (void)
 // qtractorPlugin -- Plugin instance.
 //
 
+// Default preset name (global).
+QString qtractorPlugin::g_sDefPreset = QObject::tr("(default)");
+
+
 // Constructors.
 qtractorPlugin::qtractorPlugin (
 	qtractorPluginList *pList, qtractorPluginType *pType )
 	: m_pList(pList), m_pType(pType), m_iUniqueID(0), m_iInstances(0),
-		m_bActivated(false), m_pForm(NULL), m_iDirectAccessParamIndex(-1)
+		m_bActivated(false), m_activateObserver(this),
+		m_iActivateSubjectIndex(0), m_pForm(NULL),
+		m_iDirectAccessParamIndex(-1)
 {
 	// Acquire a local unique id in chain...
 	if (m_pList && m_pType)
 		m_iUniqueID = m_pList->createUniqueID(m_pType);
+
+	// Activate subject properties.
+	m_activateSubject.setName(QObject::tr("Activate"));
+	m_activateSubject.setToggled(true);
 }
 
 
@@ -722,6 +727,25 @@ void qtractorPlugin::setInstances ( unsigned short iInstances )
 
 // Activation methods.
 void qtractorPlugin::setActivated ( bool bActivated )
+{
+	updateActivated(bActivated);
+
+	m_activateObserver.setValue(bActivated ? 1.0f : 0.0f);
+}
+
+void qtractorPlugin::setActivatedEx ( bool bActivated )
+{
+	m_activateSubject.setValue(bActivated ? 1.0f : 0.0f);
+}
+
+bool qtractorPlugin::isActivated (void) const
+{
+	return m_bActivated;
+}
+
+
+// Activation stabilizers.
+void qtractorPlugin::updateActivated ( bool bActivated )
 {
 	if (bActivated && !m_bActivated) {
 		activate();
@@ -732,6 +756,11 @@ void qtractorPlugin::setActivated ( bool bActivated )
 	}
 
 	m_bActivated = bActivated;
+}
+
+void qtractorPlugin::updateActivatedEx ( bool bActivated )
+{
+	updateActivated(bActivated);
 
 	QListIterator<qtractorPluginListItem *> iter(m_items);
 	while (iter.hasNext())
@@ -742,6 +771,22 @@ void qtractorPlugin::setActivated ( bool bActivated )
 }
 
 
+// Activate observer ctor.
+qtractorPlugin::ActivateObserver::ActivateObserver ( qtractorPlugin *pPlugin )
+	: qtractorMidiControlObserver(pPlugin->activateSubject()), m_pPlugin(pPlugin)
+{
+	setCurveList(pPlugin->list()->curveList());
+}
+
+// Activate observer updater.
+void qtractorPlugin::ActivateObserver::update ( bool bUpdate )
+{
+	qtractorMidiControlObserver::update(bUpdate);
+
+	m_pPlugin->updateActivatedEx(qtractorMidiControlObserver::value() > 0.5f);
+}
+
+
 // Plugin state serialization methods.
 void qtractorPlugin::setValueList ( const QStringList& vlist )
 {
@@ -1002,6 +1047,51 @@ bool qtractorPlugin::savePresetFile ( const QString& sFilename )
 }
 
 
+// Load an existing preset by name.
+bool qtractorPlugin::loadPresetEx ( const QString& sPreset )
+{
+	// We'll need this, sure.
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions == NULL)
+		return false;
+
+	qtractorSession *pSession = qtractorSession::getInstance();
+	if (pSession == NULL)
+		return false;
+
+	if (sPreset.isEmpty() || sPreset == g_sDefPreset) {
+		// Reset to default...
+		return pSession->execute(new qtractorResetPluginCommand(this));
+	}
+
+	bool bResult = loadPreset(sPreset);
+	if (bResult) {
+		setPreset(sPreset);
+	} else {
+		// An existing preset is about to be loaded...
+		QSettings& settings = pOptions->settings();
+		// Should it be load from known file?...
+		if (type()->isConfigure()) {
+			settings.beginGroup(presetGroup());
+			bResult = loadPresetFile(settings.value(sPreset).toString());
+			settings.endGroup();
+			if (bResult) setPreset(sPreset);
+		} else {
+			//...or make it as usual (parameter list only)...
+			settings.beginGroup(presetGroup());
+			QStringList vlist = settings.value(sPreset).toStringList();
+			settings.endGroup();
+			if (!vlist.isEmpty()) {
+				bResult = pSession->execute(
+					new qtractorPresetPluginCommand(this, sPreset, vlist));
+			}
+		}
+	}
+
+	return bResult;
+}
+
+
 // Plugin parameter lookup.
 qtractorPluginParam *qtractorPlugin::findParam ( unsigned long iIndex ) const
 {
@@ -1305,7 +1395,7 @@ void qtractorPlugin::loadCurveFile (
 
 // Save plugin automation curves (monitor, gain, pan, record, mute, solo).
 void qtractorPlugin::saveCurveFile ( qtractorDocument *pDocument,
-	QDomElement *pElement, qtractorCurveFile *pCurveFile ) const
+	QDomElement *pElement, qtractorCurveFile *pCurveFile )
 {
 	if (pCurveFile == NULL)
 		return;
@@ -1324,7 +1414,7 @@ void qtractorPlugin::saveCurveFile ( qtractorDocument *pDocument,
 
 	pCurveFile->clear();
 	pCurveFile->setBaseDir(pSession->sessionDir());
-	
+
 	unsigned short iParam = 0;
 	Params::ConstIterator param = m_params.constBegin();
 	const Params::ConstIterator param_end = m_params.constEnd();
@@ -1359,6 +1449,28 @@ void qtractorPlugin::saveCurveFile ( qtractorDocument *pDocument,
 		}
 	}
 
+	// Activate subject curve
+	qtractorCurve *pCurve = activateSubject()->curve();
+	if (pCurve) {
+		qtractorCurveFile::Item *pCurveItem = new qtractorCurveFile::Item;
+		pCurveItem->name = pCurve->subject()->name();
+		pCurveItem->index = activateSubjectIndex();
+		pCurveItem->ctype = qtractorMidiEvent::CONTROLLER;
+		pCurveItem->channel = 0;
+		const unsigned short controller = (iParam % 0x7f);
+		if (controller == 0x00 || controller == 0x20)
+			++iParam; // Avoid bank-select controllers, please.
+		pCurveItem->param = (iParam % 0x7f);
+		pCurveItem->mode = pCurve->mode();
+		pCurveItem->process = pCurve->isProcess();
+		pCurveItem->capture = pCurve->isCapture();
+		pCurveItem->locked = pCurve->isLocked();
+		pCurveItem->logarithmic = pCurve->isLogarithmic();
+		pCurveItem->color = pCurve->color();
+		pCurveItem->subject = pCurve->subject();
+		pCurveFile->addItem(pCurveItem);
+	}
+
 	if (pCurveFile->isEmpty())
 		return;
 
@@ -1376,7 +1488,7 @@ void qtractorPlugin::saveCurveFile ( qtractorDocument *pDocument,
 
 
 // Apply plugin automation curves (monitor, gain, pan, record, mute, solo).
-void qtractorPlugin::applyCurveFile ( qtractorCurveFile *pCurveFile ) const
+void qtractorPlugin::applyCurveFile ( qtractorCurveFile *pCurveFile )
 {
 	if (pCurveFile == NULL)
 		return;
@@ -1396,13 +1508,17 @@ void qtractorPlugin::applyCurveFile ( qtractorCurveFile *pCurveFile ) const
 	QListIterator<qtractorCurveFile::Item *> iter(pCurveFile->items());
 	while (iter.hasNext()) {
 		qtractorCurveFile::Item *pCurveItem = iter.next();
-		qtractorPluginParam *pParam = NULL;
-		if (!pCurveItem->name.isEmpty())
-			pParam = findParamName(pCurveItem->name);
-		if (pParam == NULL)
-			pParam = findParam(pCurveItem->index);
-		if (pParam)
-			pCurveItem->subject = pParam->subject();
+		if (pCurveItem->index == activateSubjectIndex()) {
+			pCurveItem->subject = activateSubject();
+		} else {
+			qtractorPluginParam *pParam = NULL;
+			if (!pCurveItem->name.isEmpty())
+				pParam = findParamName(pCurveItem->name);
+			if (pParam == NULL)
+				pParam = findParam(pCurveItem->index);
+			if (pParam)
+				pCurveItem->subject = pParam->subject();
+		}
 	}
 
 	pCurveFile->apply(pSession->timeScale());
@@ -1420,7 +1536,8 @@ void qtractorPluginParam::setValue ( float fValue, bool bUpdate )
 	if (m_iDecimals < 0) {
 		m_iDecimals = 0;
 		if (!isInteger()) {
-			float fDecs = ::log10f(maxValue() - minValue());
+			const float fDecs
+				= ::log10f(maxValue() - minValue());
 			if (fDecs < -3.0f)
 				m_iDecimals = 6;
 			else if (fDecs < 0.0f)
@@ -1432,6 +1549,9 @@ void qtractorPluginParam::setValue ( float fValue, bool bUpdate )
 			if (isLogarithmic())
 				++m_iDecimals;
 		}
+		// Make this permanent...
+		m_subject.setToggled(isToggled());
+		m_subject.setInteger(isInteger());
 	}
 
 	// Sanitize value...
@@ -1725,6 +1845,29 @@ void qtractorPluginList::movePlugin (
 
 	// DANGER: Gasp, we might be not the same...
 	if (pPluginList != this) {
+		// Move all plugin automation curves...
+		qtractorCurveList *pCurveList = pPluginList->curveList();
+		// Activation automation/curve...
+		qtractorCurve *pCurve = pPlugin->activateSubject()->curve();
+		if (pCurve && pCurve->list() == pCurveList) {
+			pCurveList->removeCurve(pCurve);
+			m_pCurveList->addCurve(pCurve);
+		}
+		pPlugin->activateObserver()->setCurveList(m_pCurveList);
+		// Parameters automation/curves...
+		const qtractorPlugin::Params& params = pPlugin->params();
+		qtractorPlugin::Params::ConstIterator param = params.constBegin();
+		const qtractorPlugin::Params::ConstIterator& param_end = params.constEnd();
+		for ( ; param != param_end; ++param) {
+			qtractorPluginParam *pParam = param.value();
+			pCurve = pParam->subject()->curve();
+			if (pCurve && pCurve->list() == pCurveList) {
+				pCurveList->removeCurve(pCurve);
+				m_pCurveList->addCurve(pCurve);
+			}
+			pParam->observer()->setCurveList(m_pCurveList);
+		}
+		// Now for the real thing...
 		pPlugin->setPluginList(this);
 		pPlugin->setChannels(channels());
 		if (pPlugin->isActivated()) {
@@ -1802,6 +1945,8 @@ qtractorPlugin *qtractorPluginList::copyPlugin ( qtractorPlugin *pPlugin )
 		pNewPlugin->releaseConfigs();
 		pNewPlugin->releaseValues();
 		pNewPlugin->setActivated(pPlugin->isActivated());
+		pNewPlugin->setDirectAccessParamIndex(
+			pPlugin->directAccessParamIndex());
 	}
 
 	pPlugin->releaseConfigs();
@@ -1901,15 +2046,16 @@ bool qtractorPluginList::loadElement (
 			QString sPreset;
 			QStringList vlist;
 			bool bActivated = false;
+			unsigned long iActivateSubjectIndex = 0;
 			long iDirectAccessParamIndex = -1;
 			qtractorPlugin::Configs configs;
 			qtractorPlugin::ConfigTypes ctypes;
 			qtractorPlugin::Values values;
 			qtractorMidiControl::Controllers controllers;
 			qtractorCurveFile cfile(qtractorPluginList::curveList());
+			const QString& sTypeHint = ePlugin.attribute("type");
 			qtractorPluginType::Hint typeHint
-				= qtractorPluginType::hintFromText(
-					ePlugin.attribute("type"));
+				= qtractorPluginType::hintFromText(sTypeHint);
 			for (QDomNode nParam = ePlugin.firstChild();
 					!nParam.isNull();
 						nParam = nParam.nextSibling()) {
@@ -1935,6 +2081,9 @@ bool qtractorPluginList::loadElement (
 				if (eParam.tagName() == "values")
 					vlist = eParam.text().split(',');
 				else
+				if (eParam.tagName() == "activate-subject-index")
+					iActivateSubjectIndex = eParam.text().toULong();
+				else
 				if (eParam.tagName() == "activated")
 					bActivated = qtractorDocument::boolFromText(eParam.text());
 				else
@@ -1964,6 +2113,7 @@ bool qtractorPluginList::loadElement (
 			qtractorPlugin *pPlugin
 				= qtractorPluginFile::createPlugin(this,
 					sFilename, iIndex, typeHint);
+		#if 0
 			if (!sFilename.isEmpty() && !sLabel.isEmpty() &&
 				((pPlugin == NULL) || ((pPlugin->type())->label() != sLabel))) {
 				iIndex = 0;
@@ -1972,9 +2122,12 @@ bool qtractorPluginList::loadElement (
 						sFilename, iIndex++, typeHint);
 				} while (pPlugin && (pPlugin->type())->label() != sLabel);
 			}
+		#endif
 			if (pPlugin) {
 				if (iUniqueID > 0)
 					pPlugin->setUniqueID(iUniqueID);
+				if (iActivateSubjectIndex > 0)
+					pPlugin->setActivateSubjectIndex(iActivateSubjectIndex);
 				pPlugin->setPreset(sPreset);
 				pPlugin->setConfigs(configs);
 				pPlugin->setConfigTypes(ctypes);
@@ -1987,6 +2140,10 @@ bool qtractorPluginList::loadElement (
 				pPlugin->applyCurveFile(&cfile);
 				pPlugin->setDirectAccessParamIndex(iDirectAccessParamIndex);
 				pPlugin->setActivated(bActivated); // Later's better!
+			} else {
+				qtractorMessageList::append(
+					QObject::tr("%1(%2): %3 plugin not found.")
+						.arg(sFilename).arg(iIndex).arg(sTypeHint));
 			}
 			// Cleanup.
 			qDeleteAll(controllers);
@@ -2064,6 +2221,10 @@ bool qtractorPluginList::saveElement ( qtractorDocument *pDocument,
 			QString::number(pPlugin->directAccessParamIndex()), &ePlugin);
 	//	pDocument->saveTextElement("values",
 	//		pPlugin->valueList().join(","), &ePlugin);
+		if (pPlugin->isActivateSubjectIndex()) {
+			pDocument->saveTextElement("activate-subject-index",
+				QString::number(pPlugin->activateSubjectIndex()), &ePlugin);
+		}
 		pDocument->saveTextElement("activated",
 			qtractorDocument::textFromBool(pPlugin->isActivated()), &ePlugin);
 		// Plugin configuration stuff (CLOB)...
