@@ -186,8 +186,8 @@ class qtractorPluginFile : public QLibrary
 public:
 
 	// Constructor.
-	qtractorPluginFile(const QString& sFilename, bool bAutoUnload = true)
-		: QLibrary(sFilename), m_bAutoUnload(bAutoUnload) {}
+	qtractorPluginFile(const QString& sFilename)
+		: QLibrary(sFilename) {}
 
 	// Destructor.
 	~qtractorPluginFile()
@@ -200,12 +200,6 @@ public:
 	bool open();
 	void close();
 
-	// Auto-unload flag accessors.
-	void setAutoUnload(bool bAutoUnload)
-		{ m_bAutoUnload = bAutoUnload; }
-	bool isAutoUnload() const
-		{ return m_bAutoUnload; }
-	
 	// Plugin type listing.
 	bool getTypes(qtractorPluginPath& path,
 		qtractorPluginType::Hint typeHint = qtractorPluginType::Any);
@@ -214,11 +208,6 @@ public:
 	static qtractorPlugin *createPlugin(qtractorPluginList *pList,
 		const QString& sFilename, unsigned long iIndex = 0,
 		qtractorPluginType::Hint typeHint = qtractorPluginType::Any);
-
-private:
-
-	// Instance variables.
-	bool m_bAutoUnload;
 };
 
 
@@ -362,7 +351,7 @@ private:
 
 	// Instance variables.
 	qtractorPlugin *m_pPlugin;
-	unsigned long m_iIndex;
+	unsigned long   m_iIndex;
 
 	// Port subject value.
 	qtractorSubject m_subject;
@@ -378,7 +367,7 @@ private:
 	protected:
 
 		// Virtual observer updater.
-		void update(bool Update);
+		void update(bool bUpdate);
 
 	private:
 
@@ -428,8 +417,23 @@ public:
 
 	// Activation methods.
 	void setActivated(bool bActivated);
-	bool isActivated() const
-		{ return m_bActivated; }
+	void setActivatedEx(bool bActivated);
+	bool isActivated() const;
+
+	// Activate subject accessors.
+	qtractorSubject *activateSubject()
+		{ return &m_activateSubject; }
+	qtractorMidiControlObserver *activateObserver()
+		{ return &m_activateObserver; }
+
+	// Activate pseudo-parameter port index.
+	void setActivateSubjectIndex (unsigned long iIndex)
+		{ m_iActivateSubjectIndex = iIndex; }
+	unsigned long activateSubjectIndex() const
+		{ return m_iActivateSubjectIndex; }
+
+	bool isActivateSubjectIndex() const
+		{ return int(m_iActivateSubjectIndex) > m_params.count(); }
 
 	// An accessible list of parameters.
 	typedef QHash<unsigned long, qtractorPluginParam *> Params;
@@ -443,10 +447,13 @@ public:
 	// Parameter list accessor.
 	void addParam(qtractorPluginParam *pParam)
 	{
+		pParam->reset();
 		if (pParam->isLogarithmic())
 			pParam->observer()->setLogarithmic(true);
 		m_params.insert(pParam->index(), pParam);
 		m_paramNames.insert(pParam->name(), pParam);
+		if (pParam->index() >= m_iActivateSubjectIndex)
+			m_iActivateSubjectIndex = pParam->index() + 1;
 	}
 
 	// Instance capped number of audio ports.
@@ -557,10 +564,17 @@ public:
 	QString presetGroup() const;
 	QString presetPrefix() const;
 
+	// Default preset name (global).
+	static const QString& defPreset()
+		{ return g_sDefPreset; }
+
 	// Plugin configuration from/to xml file.
 	bool loadPresetFile(const QString& sFilename);
 	bool savePresetFile(const QString& sFilename);
 
+	// Load an existing preset by name.
+	bool loadPresetEx(const QString& sPreset);
+
 	// Plugin parameter lookup.
 	qtractorPluginParam *findParam(unsigned long iIndex) const;
 	qtractorPluginParam *findParamName(const QString& sName) const;
@@ -642,8 +656,8 @@ public:
 	static void loadCurveFile(
 	    QDomElement *pElement, qtractorCurveFile *pCurveFile);
 	void saveCurveFile(qtractorDocument *pDocument,
-		QDomElement *pElement, qtractorCurveFile *pCurveFile) const;
-	void applyCurveFile (qtractorCurveFile *pCurveFile) const;
+		QDomElement *pElement, qtractorCurveFile *pCurveFile);
+	void applyCurveFile (qtractorCurveFile *pCurveFile);
 
 	// Direct access parameter accessors.
 	qtractorPluginParam *directAccessParam() const;
@@ -660,6 +674,10 @@ protected:
 	// Instance number settler.
 	void setInstances(unsigned short iInstances);
 
+	// Activation stabilizers.
+	void updateActivated(bool bActivated);
+	void updateActivatedEx(bool bActivated);
+
 private:
 
 	// Instance variables.
@@ -675,6 +693,32 @@ private:
 	// Activation flag.
 	bool m_bActivated;
 
+	// Activate subject value.
+	qtractorSubject m_activateSubject;
+
+	// Activate observer manager.
+	class ActivateObserver : public qtractorMidiControlObserver
+	{
+	public:
+
+		// Constructor.
+		ActivateObserver(qtractorPlugin *pPlugin);
+
+	protected:
+
+		// Virtual observer updater.
+		void update(bool bUpdate);
+
+	private:
+
+		// Instance members.
+		qtractorPlugin *m_pPlugin;
+
+	} m_activateObserver;
+
+	// Activate pseudo-parameter port index.
+	unsigned long m_iActivateSubjectIndex;
+
 	// List of input control ports (parameters).
 	Params m_params;
 
@@ -702,6 +746,9 @@ private:
 
 	// Direct access parameter, if any.
 	long m_iDirectAccessParamIndex;
+
+	// Default preset name.
+	static QString g_sDefPreset;
 };
 
 
