@@ -777,6 +777,30 @@ void qtractorPluginListView::moveDownPlugin (void)
 }
 
 
+// Load a plugin preset name.
+void qtractorPluginListView::loadPresetPlugin (void)
+{
+	if (m_pPluginList == NULL)
+		return;
+
+	qtractorPluginListItem *pItem
+		= static_cast<qtractorPluginListItem *> (QListWidget::currentItem());
+	if (pItem == NULL)
+		return;
+
+	qtractorPlugin *pPlugin = pItem->plugin();
+	if (pPlugin == NULL)
+		return;
+
+	// Retrieve preset-name from action text...
+	QAction *pAction = qobject_cast<QAction *> (sender());
+	if (pAction == NULL)
+		return;
+
+	pPlugin->loadPresetEx(pAction->text());
+}
+
+
 // Select a direct access parameter index.
 void qtractorPluginListView::directAccessPlugin (void)
 {
@@ -1010,6 +1034,10 @@ void qtractorPluginListView::itemActivatedSlot ( QListWidgetItem *item )
 	if (pOptions)
 		bOpenEditor = pOptions->bOpenEditor;
 
+	if (QApplication::keyboardModifiers()
+		& (Qt::ShiftModifier | Qt::ControlModifier))
+		bOpenEditor = !bOpenEditor;
+
 	if (bOpenEditor && (pPlugin->type())->isEditor())
 		pPlugin->openEditor(this);
 	else
@@ -1086,8 +1114,12 @@ void qtractorPluginListView::wheelEvent ( QWheelEvent *pWheelEvent )
 			fValue = pDirectAccessObserver->valueFromScale(
 				fScale + fDelta, bLogarithmic);
 			pDirectAccessParam->updateValue(fValue, true);
+			return;
 		}
 	}
+
+	// Not handled here.
+	QListWidget::wheelEvent(pWheelEvent);
 }
 
 
@@ -1489,6 +1521,25 @@ void qtractorPluginListView::contextMenuEvent (
 
 	menu.addSeparator();
 
+	QMenu *pPresetMenu = menu.addMenu("Preset");
+	if (pPlugin) {
+		const QStringList& presets = pPlugin->presetList();
+		QStringListIterator iter(presets);
+		while (iter.hasNext()) {
+			const QString& sPreset = iter.next();
+			pAction = pPresetMenu->addAction(
+				sPreset, this, SLOT(loadPresetPlugin()));
+			pAction->setCheckable(true);
+			pAction->setChecked(sPreset == pPlugin->preset());
+		}
+		if (presets.count() > 0)
+			pPresetMenu->addSeparator();
+		pAction = pPresetMenu->addAction(
+			qtractorPlugin::defPreset(), this, SLOT(loadPresetPlugin()));
+		pAction->setCheckable(false);
+	}
+	pPresetMenu->setEnabled(pPlugin != NULL);
+
 	QMenu *pDirectAccessParamMenu = menu.addMenu("Dire&ct Access");
 	if (pPlugin) {
 		const int iDirectAccessParamIndex = pPlugin->directAccessParamIndex();
@@ -1670,4 +1721,13 @@ void qtractorPluginListView::dragDirectAccess ( const QPoint& pos )
 }
 
 
+// Initial size-policy hints.
+QSize qtractorPluginListView::sizeHint (void) const
+{
+	const QFont& font = QListWidget::font();
+	const int iItemHeight = QFontMetrics(font).lineSpacing() + 4;
+	return QSize(320, iItemHeight << 2);
+}
+
+
 // end of qtractorPluginListView.cpp
