@@ -127,6 +127,7 @@ public slots:
 	void removePlugin();
 	void moveUpPlugin();
 	void moveDownPlugin();
+	void loadPresetPlugin();
 	void directAccessPlugin();
 	void propertiesPlugin();
 	void editPlugin();
@@ -207,6 +208,9 @@ protected:
 	// Direct access parameter handle.
 	void dragDirectAccess(const QPoint& pos);
 
+	// Initial size-policy hints.
+	QSize sizeHint() const;
+
 private:
 
 	// Instance variables.
