@@ -83,37 +83,22 @@ qtractorSession::Properties& qtractorSession::Properties::copy (
 //-------------------------------------------------------------------------
 // qtractorSession -- Session container.
 
-// Singleton instance pointer.
+// pSeudo-singleton instance pointer.
 qtractorSession *qtractorSession::g_pSession = NULL;
 
 
-// Singleton instance accessor (static).
+// Pseudo-singleton instance accessor (static).
 qtractorSession *qtractorSession::getInstance (void)
 {
-	// Create the singleton instance, if not already...
-	if (g_pSession == NULL) {
-		g_pSession = new qtractorSession();
-		::atexit(Destroy);
-	}
-
 	return g_pSession;
 }
 
 
-// Singleton instance destroyer.
-void qtractorSession::Destroy (void)
-{
-	// OK. We're done with ourselves.
-	if (g_pSession) {
-		delete g_pSession;
-		g_pSession = NULL;
-	}
-}
-
-
 // Constructor.
 qtractorSession::qtractorSession (void)
 {
+	g_pSession = this;
+
 	m_tracks.setAutoDelete(true);
 	m_cursors.setAutoDelete(false);
 
@@ -154,6 +139,8 @@ qtractorSession::~qtractorSession (void)
 	delete m_pCommands;
 
 	delete m_pFiles;
+
+	g_pSession = NULL;
 }
 
 
@@ -164,7 +151,7 @@ bool qtractorSession::init (void)
 	lock();
 
 	//  Actually init session device engines...
-	bool bResult = (m_pAudioEngine->init() && m_pMidiEngine->init());
+	const bool bResult = (m_pAudioEngine->init() && m_pMidiEngine->init());
 
 	// Done.
 	unlock();
@@ -806,7 +793,8 @@ void qtractorSession::updateSampleRate ( unsigned int iSampleRate )
 	}
 
 	// Set the conversion ratio...
-	float fRatio = float(m_props.timeScale.sampleRate()) / float(iSampleRate);
+	const float fRatio
+		= float(m_props.timeScale.sampleRate()) / float(iSampleRate);
 
 	// Set actual sample-rate...
 	m_props.timeScale.setSampleRate(iSampleRate);
@@ -1154,10 +1142,10 @@ void qtractorSession::setPlaying ( bool bPlaying )
 	if (bPlaying && isRecording()) {
 		// Take a snapshot on where recording
 		// clips are about to start...
-		unsigned long iPlayHead  = playHead();
+		const unsigned long iPlayHead  = playHead();
 		unsigned long iClipStart = iPlayHead;
 		if (isPunching()) {
-			unsigned long iPunchIn = punchIn();
+			const unsigned long iPunchIn = punchIn();
 			if (iClipStart < iPunchIn)
 				iClipStart = iPunchIn;
 		}
@@ -1277,7 +1265,7 @@ bool qtractorSession::isBusy (void) const
 // Playhead positioning.
 void qtractorSession::setPlayHead ( unsigned long iFrame )
 {
-	bool bPlaying = isPlaying();
+	const bool bPlaying = isPlaying();
 	if (bPlaying && isRecording())
 		return;
 
@@ -1307,7 +1295,7 @@ unsigned long qtractorSession::playHead (void) const
 void qtractorSession::setLoop ( unsigned long iLoopStart,
 	unsigned long iLoopEnd )
 {
-	bool bPlaying = isPlaying();
+	const bool bPlaying = isPlaying();
 	if (bPlaying && isRecording())
 		return;
 
@@ -1321,7 +1309,7 @@ void qtractorSession::setLoop ( unsigned long iLoopStart,
 	}
 
 	// Save exact current play-head position...
-	unsigned long iFrame = playHead();
+	const unsigned long iFrame = playHead();
 
 	// Set proper loop points for every track, clip and buffer...
 	qtractorTrack *pTrack = m_tracks.first();
@@ -1460,12 +1448,12 @@ void qtractorSession::setRecording ( bool bRecording )
 	unsigned long iClipStart = playHead();
 
 	if (isPunching()) {
-		unsigned long iPunchIn = punchIn();
+		const unsigned long iPunchIn = punchIn();
 		if (iClipStart < iPunchIn)
 			iClipStart = iPunchIn;
 	}
 
-	unsigned long iFrameTime = frameTimeEx();
+	const unsigned long iFrameTime = frameTimeEx();
 	for (qtractorTrack *pTrack = m_tracks.first();
 			pTrack; pTrack = pTrack->next()) {
 		if (pTrack->isRecord())
@@ -1560,8 +1548,8 @@ void qtractorSession::trackRecord (
 		// MIDI adjust to playing queue start
 		// iif armed while already playing ...
 		if (isPlaying()) {
-			unsigned long iTime = pMidiClip->clipStartTime();
-			unsigned long iTimeStart = m_pMidiEngine->timeStart();
+			const unsigned long iTime = pMidiClip->clipStartTime();
+			const unsigned long iTimeStart = m_pMidiEngine->timeStart();
 			if (iTime > iTimeStart)
 				pMidiClip->sequence()->setTimeOffset(iTime - iTimeStart);
 		}
@@ -1661,7 +1649,7 @@ void qtractorSession::acquireMidiTag ( qtractorTrack *pTrack )
 
 void qtractorSession::releaseMidiTag ( qtractorTrack *pTrack )
 {
-	unsigned short iMidiTag = pTrack->midiTag();
+	const unsigned short iMidiTag = pTrack->midiTag();
 	if (iMidiTag > 0) {
 		m_midiTags.push_back(iMidiTag);
 		pTrack->setMidiTag(0);
@@ -1670,7 +1658,7 @@ void qtractorSession::releaseMidiTag ( qtractorTrack *pTrack )
 
 
 // MIDI session/tracks instrument/controller patching (conditional).
-void qtractorSession::setMidiPatch ( bool bForceImmediate )
+void qtractorSession::resetAllMidiControllers ( bool bForceImmediate )
 {
 	if (!bForceImmediate || m_pMidiEngine->isResetAllControllers())
 		m_pMidiEngine->resetAllControllers(bForceImmediate);
@@ -1918,7 +1906,8 @@ bool qtractorSession::loadElement (
 					continue;
 				// Load tempo-map...
 				if (eNode.tagName() == "tempo-node") {
-					unsigned long iFrame = eNode.attribute("frame").toULong();
+					const unsigned long iFrame
+						= eNode.attribute("frame").toULong();
 					float fTempo = 120.0f;
 					unsigned short iBeatType = 2;
 					unsigned short iBeatsPerBar = 4;
@@ -1959,7 +1948,8 @@ bool qtractorSession::loadElement (
 					continue;
 				// Load markers...
 				if (eMarker.tagName() == "marker") {
-					unsigned long iFrame = eMarker.attribute("frame").toULong();
+					const unsigned long iFrame
+						= eMarker.attribute("frame").toULong();
 					QString sText;
 					QColor rgbColor = Qt::darkGray;
 					for (QDomNode nItem = eMarker.firstChild();
