@@ -52,6 +52,9 @@ class qtractorSession
 {
 public:
 
+	// Constructor.
+	qtractorSession();
+
 	// Default destructor.
 	~qtractorSession();
 
@@ -309,7 +312,7 @@ public:
 	void releaseMidiTag(qtractorTrack *pTrack);
 
 	// MIDI session/tracks instrument/controller patching (conditional).
-	void setMidiPatch(bool bForceImmediate);
+	void resetAllMidiControllers(bool bForceImmediate);
 
 	// MIDI manager list accessors.
 	void addMidiManager(qtractorMidiManager *pMidiManager);
@@ -378,17 +381,9 @@ public:
 	// Session files registry accessor.
 	qtractorFileList *files() const;
 
-	// Singleton instance accessor.
+	// Pseudo-singleton instance accessor.
 	static qtractorSession *getInstance();
 
-	// Singleton destroyer.
-	static void Destroy();
-
-protected:
-
-	// Constructor.
-	qtractorSession();
-
 private:
 
 	Properties     m_props;             // Session properties.
@@ -478,7 +473,7 @@ private:
 	// File registry.
 	qtractorFileList *m_pFiles;
 
-	// The singleton instance.
+	// The pseudo-singleton instance.
 	static qtractorSession *g_pSession;
 };
 
