@@ -1,7 +1,7 @@
 // qtractorTrack.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -68,7 +68,7 @@ protected:
 	// Update feedback.
 	void update(bool bUpdate)
 	{
-		bool bOn = (value() > 0.0f);
+		const bool bOn = (value() > 0.0f);
 		switch (m_toolType) {
 		case qtractorTrack::Record:
 			m_pTrack->setRecord(bOn);
@@ -282,7 +282,7 @@ int qtractorTrack::takeInfoNew ( qtractorTrack::TakeInfo *pTakeInfo ) const
 	if (iter != m_takeids.constEnd()) {
 		return iter.value();
 	} else {
-		int iTakeID = m_takeids.count();
+		const int iTakeID = m_takeids.count();
 		takeInfoAdd(iTakeID, pTakeInfo);
 		return iTakeID;
 	}
@@ -738,11 +738,11 @@ void qtractorTrack::setRecord ( bool bRecord )
 	if (m_pSession->isRecording()) {
 		unsigned long iClipStart = m_pSession->playHead();
 		if (m_pSession->isPunching()) {
-			unsigned long iPunchIn = m_pSession->punchIn();
+			const unsigned long iPunchIn = m_pSession->punchIn();
 			if (iClipStart < iPunchIn)
 				iClipStart = iPunchIn;
 		}
-		unsigned long iFrameTime = m_pSession->frameTimeEx();
+		const unsigned long iFrameTime = m_pSession->frameTimeEx();
 		m_pSession->trackRecord(this, bRecord, iClipStart, iFrameTime);
 	}
 }
@@ -1162,7 +1162,7 @@ const QColor& qtractorTrack::foreground (void) const
 // Generate a default track color.
 QColor qtractorTrack::trackColor ( int iTrack )
 {
-	int c[3] = { 0xff, 0xcc, 0x99 };
+	const int c[3] = { 0xff, 0xcc, 0x99 };
 
 	return QColor(c[iTrack % 3], c[(iTrack / 3) % 3], c[(iTrack / 9) % 3]);
 }
@@ -1180,7 +1180,7 @@ void qtractorTrack::process ( qtractorClip *pClip,
 	unsigned long iFrameStart, unsigned long iFrameEnd )
 {
 	// Audio-buffers needs some preparation...
-	unsigned int nframes = iFrameEnd - iFrameStart;
+	const unsigned int nframes = iFrameEnd - iFrameStart;
 	qtractorAudioMonitor *pAudioMonitor = NULL;
 	qtractorAudioBus *pOutputBus = NULL;
 	if (m_props.trackType == qtractorTrack::Audio) {
@@ -1230,8 +1230,8 @@ void qtractorTrack::process_record (
 		unsigned int nframes = iFrameEnd - iFrameStart;
 		if (m_pSession->isPunching()) {
 			// Punch-in/out recording...
-			unsigned long iPunchIn  = m_pSession->punchIn();
-			unsigned long iPunchOut = m_pSession->punchOut();
+			const unsigned long iPunchIn  = m_pSession->punchIn();
+			const unsigned long iPunchOut = m_pSession->punchOut();
 			if (iPunchIn < iFrameEnd && iPunchOut > iFrameStart) {
 				unsigned int offs = 0;
 				// Punch-out (unlikely...)
@@ -1359,8 +1359,8 @@ void qtractorTrack::setLoop (
 	qtractorClip *pClip = m_clips.first();
 	while (pClip) {
 		// Convert loop-points from session to clip...
-		unsigned long iClipStart = pClip->clipStart();
-		unsigned long iClipEnd   = iClipStart + pClip->clipLength();
+		const unsigned long iClipStart = pClip->clipStart();
+		const unsigned long iClipEnd   = iClipStart + pClip->clipLength();
 		if (iLoopStart < iClipEnd && iLoopEnd > iClipStart) {
 			// Set clip inner-loop...
 			pClip->setLoop(
@@ -1378,7 +1378,7 @@ void qtractorTrack::setLoop (
 // MIDI track instrument patching.
 void qtractorTrack::setMidiPatch ( qtractorInstrumentList *pInstruments )
 {
-	int iProg = midiProg();
+	const int iProg = midiProg();
 	if (iProg < 0)
 		return;
 
@@ -1387,9 +1387,10 @@ void qtractorTrack::setMidiPatch ( qtractorInstrumentList *pInstruments )
 	if (pMidiBus == NULL)
 		return;
 
-	unsigned short iChannel = midiChannel();
+	const unsigned short iChannel = midiChannel();
 	const qtractorMidiBus::Patch& patch = pMidiBus->patch(iChannel);
-	int iBank = midiBank();
+	const int iBank = midiBank();
+
 	int iBankSelMethod = midiBankSelMethod();
 	if (iBankSelMethod < 0) {
 		if (!patch.instrumentName.isEmpty())
@@ -1826,6 +1827,8 @@ void qtractorTrack::saveControllers (
 		pController->param = m_pMonitorObserver->param();
 		pController->logarithmic = m_pMonitorObserver->isLogarithmic();
 		pController->feedback = m_pMonitorObserver->isFeedback();
+		pController->invert = m_pMonitorObserver->isInvert();
+		pController->hook = m_pMonitorObserver->isHook();
 		controllers.append(pController);
 	}
 
@@ -1841,6 +1844,8 @@ void qtractorTrack::saveControllers (
 		pController->param = pPanObserver->param();
 		pController->logarithmic = pPanObserver->isLogarithmic();
 		pController->feedback = pPanObserver->isFeedback();
+		pController->invert = pPanObserver->isInvert();
+		pController->hook = pPanObserver->isHook();
 		controllers.append(pController);
 	}
 
@@ -1856,6 +1861,8 @@ void qtractorTrack::saveControllers (
 		pController->param = pGainObserver->param();
 		pController->logarithmic = pGainObserver->isLogarithmic();
 		pController->feedback = pGainObserver->isFeedback();
+		pController->invert = pGainObserver->isInvert();
+		pController->hook = pGainObserver->isHook();
 		controllers.append(pController);
 	}
 
@@ -1869,6 +1876,8 @@ void qtractorTrack::saveControllers (
 		pController->param = m_pRecordObserver->param();
 		pController->logarithmic = m_pRecordObserver->isLogarithmic();
 		pController->feedback = m_pRecordObserver->isFeedback();
+		pController->invert = m_pRecordObserver->isInvert();
+		pController->hook = m_pRecordObserver->isHook();
 		controllers.append(pController);
 	}
 
@@ -1882,6 +1891,8 @@ void qtractorTrack::saveControllers (
 		pController->param = m_pMuteObserver->param();
 		pController->logarithmic = m_pMuteObserver->isLogarithmic();
 		pController->feedback = m_pMuteObserver->isFeedback();
+		pController->invert = m_pMuteObserver->isInvert();
+		pController->hook = m_pMuteObserver->isHook();
 		controllers.append(pController);
 	}
 
@@ -1895,6 +1906,8 @@ void qtractorTrack::saveControllers (
 		pController->param = m_pSoloObserver->param();
 		pController->logarithmic = m_pSoloObserver->isLogarithmic();
 		pController->feedback = m_pSoloObserver->isFeedback();
+		pController->invert = m_pSoloObserver->isInvert();
+		pController->hook = m_pSoloObserver->isHook();
 		controllers.append(pController);
 	}
 
@@ -1955,6 +1968,8 @@ void qtractorTrack::mapControllers (void)
 			pObserver->setParam(pController->param);
 			pObserver->setLogarithmic(pController->logarithmic);
 			pObserver->setFeedback(pController->feedback);
+			pObserver->setInvert(pController->invert);
+			pObserver->setHook(pController->hook);
 			pMidiControl->mapMidiObserver(pObserver);
 		}
 	}
@@ -2133,7 +2148,7 @@ void qtractorTrack::saveCurveFile ( qtractorDocument *pDocument,
 		return;
 
 	const QString sBaseName(trackName() + "_curve");
-	int iClipNo = (pCurveFile->filename().isEmpty() ? 0 : 1);
+	const int iClipNo = (pCurveFile->filename().isEmpty() ? 0 : 1);
 	pCurveFile->setFilename(pSession->createFilePath(sBaseName, "mid", iClipNo));
 
 	pCurveFile->save(pDocument, pElement, pSession->timeScale());
