@@ -166,7 +166,7 @@ void qtractorTracks::horizontalZoomStep ( int iZoomStep )
 	qtractorSession *pSession = qtractorSession::getInstance();
 	if (pSession == NULL)
 		return;
-		
+
 	int iHorizontalZoom = pSession->horizontalZoom() + iZoomStep;
 	if (iHorizontalZoom < ZoomMin)
 		iHorizontalZoom = ZoomMin;
@@ -210,6 +210,7 @@ void qtractorTracks::setZoomMode ( int iZoomMode )
 	m_iZoomMode = iZoomMode;
 }
 
+
 int qtractorTracks::zoomMode (void) const
 {
 	return m_iZoomMode;
@@ -230,6 +231,7 @@ void qtractorTracks::zoomIn (void)
 	zoomCenterPost(zc);
 }
 
+
 void qtractorTracks::zoomOut (void)
 {
 	ZoomCenter zc;
@@ -262,42 +264,61 @@ void qtractorTracks::zoomReset (void)
 }
 
 
+// Zoom step evaluator.
+int qtractorTracks::zoomStep (void) const
+{
+	const Qt::KeyboardModifiers& modifiers
+		= QApplication::keyboardModifiers();
+
+	if (modifiers & Qt::ControlModifier)
+		return ZoomMax;
+	if (modifiers & Qt::ShiftModifier)
+		return ZoomBase >> 1;
+
+	return ZoomStep;
+}
+
+
 void qtractorTracks::horizontalZoomInSlot (void)
 {
 	ZoomCenter zc;
 	zoomCenterPre(zc);
 
-	horizontalZoomStep(+ ZoomStep);
+	horizontalZoomStep(+ zoomStep());
 	zoomCenterPost(zc);
 }
 
+
 void qtractorTracks::horizontalZoomOutSlot (void)
 {
 	ZoomCenter zc;
 	zoomCenterPre(zc);
 
-	horizontalZoomStep(- ZoomStep);
+	horizontalZoomStep(- zoomStep());
 	zoomCenterPost(zc);
 }
 
+
 void qtractorTracks::verticalZoomInSlot (void)
 {
 	ZoomCenter zc;
 	zoomCenterPre(zc);
 
-	verticalZoomStep(+ ZoomStep);
+	verticalZoomStep(+ zoomStep());
 	zoomCenterPost(zc);
 }
 
+
 void qtractorTracks::verticalZoomOutSlot (void)
 {
 	ZoomCenter zc;
 	zoomCenterPre(zc);
 
-	verticalZoomStep(- ZoomStep);
+	verticalZoomStep(- zoomStep());
 	zoomCenterPost(zc);
 }
 
+
 void qtractorTracks::viewZoomResetSlot (void)
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
@@ -1633,11 +1654,13 @@ bool qtractorTracks::rangeClip ( qtractorClip *pClip )
 	return rangeClipEx(pClip, false);
 }
 
+
 bool qtractorTracks::loopClip ( qtractorClip *pClip )
 {
 	return rangeClipEx(pClip, true);
 }
 
+
 bool qtractorTracks::rangeClipEx ( qtractorClip *pClip, bool bLoopSet )
 {
 	qtractorSession *pSession = qtractorSession::getInstance();
@@ -1809,6 +1832,7 @@ void qtractorTracks::cutClipboard (void)
 		m_pTrackView->executeClipSelect(qtractorTrackView::Cut);
 }
 
+
 void qtractorTracks::copyClipboard (void)
 {
 	if (m_pTrackView->isCurveEdit())
@@ -1817,6 +1841,7 @@ void qtractorTracks::copyClipboard (void)
 		m_pTrackView->executeClipSelect(qtractorTrackView::Copy);
 }
 
+
 void qtractorTracks::pasteClipboard (void)
 {
 	m_pTrackView->pasteClipboard();
@@ -2119,7 +2144,8 @@ int qtractorTracks::insertEditRangeTrack (
 				qtractorCurve::Node *pNode = pCurve->seek(iInsertStart);
 				while (pNode) {
 					pCurveEditCommand->moveNode(pNode,
-						pNode->frame + iInsertLength);
+						pNode->frame + iInsertLength,
+						pNode->value);
 					++iCurveEditUpdate;
 					pNode = pNode->next();
 				}
@@ -2388,7 +2414,8 @@ int qtractorTracks::removeEditRangeTrack (
 						pCurveEditCommand->removeNode(pNode);
 					else
 						pCurveEditCommand->moveNode(pNode,
-							pNode->frame - iRemoveLength);
+							pNode->frame - iRemoveLength,
+							pNode->value);
 					++iCurveEditUpdate;
 					pNode = pNode->next();
 				}
@@ -2653,7 +2680,7 @@ bool qtractorTracks::addMidiTracks (
 		if (!file.open(sPath))
 			continue;
 		// It all depends on the format...
-		int iTracks = (file.format() == 1 ? file.tracks() : 16);
+		const int iTracks = (file.format() == 1 ? file.tracks() : 16);
 		for (int iTrackChannel = 0; iTrackChannel < iTracks; ++iTrackChannel) {
 			// Create a new track right away...
 			const QColor& color = qtractorTrack::trackColor(++iTrack);
@@ -2793,7 +2820,7 @@ void qtractorTracks::updateTrack ( qtractorTrack *pTrack )
 {
 	m_pTrackList->updateTrack(pTrack);
 
-	if (pTrack->trackType() == qtractorTrack::Midi)
+	if (pTrack && pTrack->trackType() == qtractorTrack::Midi)
 		updateMidiTrack(pTrack);
 }
 
@@ -2876,9 +2903,9 @@ void qtractorTracks::dirtyChangeNotify (void)
 
 
 // Track-list update (current track only).
-void qtractorTracks::updateTrackList (void)
+void qtractorTracks::updateTrackList ( qtractorTrack *pTrack )
 {
-	m_pTrackList->updateTrack(currentTrack());
+	m_pTrackList->updateTrack(pTrack);
 }
 
 
