@@ -75,7 +75,8 @@ public:
 		unsigned long iClipStart = 0);
 
 	// Track-list active maintenance update.
-	void updateTrack(qtractorTrack *pTrack);
+	void updateTrack(qtractorTrack *pTrack = NULL);
+
 	// MIDI track/bus/channel alias active maintenance method.
 	void updateMidiTrack(qtractorTrack *pMidiTrack);
 
@@ -161,13 +162,16 @@ public:
 	void zoomReset();
 
 	// Track-list update (current track only).
-	void updateTrackList();
+	void updateTrackList(qtractorTrack *pTrack = NULL);
 
 protected:
 
 	// Zoom factor constants.
 	enum { ZoomMin = 10, ZoomBase = 100, ZoomMax = 1000, ZoomStep = 10 };
 
+	// Zoom step evaluator.
+	int zoomStep() const;
+
 	// Common zoom factor settlers.
 	void horizontalZoomStep(int iZoomStep);
 	void verticalZoomStep(int iZoomStep);
