@@ -454,11 +454,6 @@ bool qtractorVstPluginType::open (void)
 	m_bConfigure = (pVstEffect->flags & effFlagsProgramChunks);
 	m_bEditor    = (pVstEffect->flags & effFlagsHasEditor);
 
-	// HACK: JUCE based VST plugins, which are the most found
-	// with a GUI editor, need to skip explicit shared library
-	// unloading, to avoid mysterious crashes later...
-	if (m_bEditor) file()->setAutoUnload(false);
-
 	return true;
 }
 
@@ -561,7 +556,8 @@ const QString& qtractorVstPluginType::aboutText (void)
 			m_sAboutText += QObject::tr("Vendor: ");
 			m_sAboutText += szTemp;
 		}
-		const int iVersion = vst_dispatch(effGetVendorVersion, 0, 0, NULL, 0.0f);
+		const int iVersion
+			= vst_dispatch(effGetVendorVersion, 0, 0, NULL, 0.0f);
 		if (iVersion) {
 			if (!m_sAboutText.isEmpty())
 				m_sAboutText += '\n';
@@ -582,10 +578,11 @@ const QString& qtractorVstPluginType::aboutText (void)
 static QHash<AEffect *, qtractorVstPlugin *> g_vstPlugins;
 
 // Constructors.
-qtractorVstPlugin::qtractorVstPlugin ( qtractorPluginList *pList,
-	qtractorVstPluginType *pVstType )
+qtractorVstPlugin::qtractorVstPlugin (
+	qtractorPluginList *pList, qtractorVstPluginType *pVstType )
 	: qtractorPlugin(pList, pVstType), m_ppEffects(NULL),
-		m_ppIBuffer(NULL), m_ppOBuffer(NULL), m_pEditorWidget(NULL)
+		m_ppIBuffer(NULL), m_ppOBuffer(NULL),
+		m_pEditorWidget(NULL), m_bEditorClosed(false)
 {
 #ifdef CONFIG_DEBUG
 	qDebug("qtractorVstPlugin[%p] filename=\"%s\" index=%lu typeHint=%d",
@@ -594,15 +591,15 @@ qtractorVstPlugin::qtractorVstPlugin ( qtractorPluginList *pList,
 #endif
 
 	// Allocate I/O audio buffer pointers.
-	unsigned short iAudioIns  = pVstType->audioIns();
-	unsigned short iAudioOuts = pVstType->audioOuts();
+	const unsigned short iAudioIns  = pVstType->audioIns();
+	const unsigned short iAudioOuts = pVstType->audioOuts();
 	if (iAudioIns > 0)
 		m_ppIBuffer = new float * [iAudioIns];
 	if (iAudioOuts > 0)
 		m_ppOBuffer = new float * [iAudioOuts];
 
 	// Create all existing parameters...
-	unsigned short iParamCount = pVstType->controlIns();
+	const unsigned short iParamCount = pVstType->controlIns();
 	for (unsigned short i = 0; i < iParamCount; ++i)
 		addParam(new qtractorVstPluginParam(this, i));
 
@@ -635,15 +632,15 @@ void qtractorVstPlugin::setChannels ( unsigned short iChannels )
 		return;
 		
 	// Estimate the (new) number of instances...
-	unsigned short iOldInstances = instances();
-	unsigned short iInstances
+	const unsigned short iOldInstances = instances();
+	const unsigned short iInstances
 		= pVstType->instances(iChannels, list()->isMidi());
 	// Now see if instance count changed anyhow...
 	if (iInstances == iOldInstances)
 		return;
 
 	// Gotta go for a while...
-	bool bActivated = isActivated();
+	const bool bActivated = isActivated();
 	setActivated(false);
 
 	// Set new instance number...
@@ -755,8 +752,8 @@ void qtractorVstPlugin::process (
 	const unsigned short iAudioIns  = audioIns();
 	const unsigned short iAudioOuts = audioOuts();
 
-	unsigned short iIChannel  = 0;
-	unsigned short iOChannel  = 0;
+	unsigned short iIChannel = 0;
+	unsigned short iOChannel = 0;
 	unsigned short i, j;
 
 	// For each plugin instance...
@@ -791,11 +788,13 @@ void qtractorVstPlugin::process (
 				pVstEffect, m_ppIBuffer, m_ppOBuffer, nframes);
 		}
 	#endif
+	#if 0
 		// Wrap channels?...
 		if (iIChannel < iChannels - 1)
 			++iIChannel;
 		if (iOChannel < iChannels - 1)
 			++iOChannel;
+	#endif
 	}
 
 	if (pMidiManager && iMidiOuts > 0)
@@ -898,7 +897,7 @@ void qtractorVstPlugin::configure ( const QString& sKey, const QString& sValue )
 		// Load the BLOB (base64 encoded)...
 		QByteArray data = qUncompress(QByteArray::fromBase64(sValue.toLatin1()));
 		const char *pData = data.constData();
-		int iData = data.size();
+		const int iData = data.size();
 	#ifdef CONFIG_DEBUG
 		qDebug("qtractorVstPlugin[%p]::configure() chunk.size=%d checksum=0x%04x",
 			this, iData, qChecksum(pData, iData));
@@ -926,7 +925,8 @@ void qtractorVstPlugin::freezeConfigs (void)
 
 	// Save plugin state into chunk configuration...
 	char *pData = NULL;
-	int iData = vst_dispatch(0, effGetChunk, 0, 0, (void *) &pData, 0.0f);
+	const int iData
+		= vst_dispatch(0, effGetChunk, 0, 0, (void *) &pData, 0.0f);
 	if (iData < 1 || pData == NULL)
 		return;
 
@@ -1008,6 +1008,11 @@ void qtractorVstPlugin::openEditor ( QWidget */*pParent*/ )
 // Close editor.
 void qtractorVstPlugin::closeEditor (void)
 {
+	if (m_bEditorClosed)
+		return;
+
+	m_bEditorClosed = true;
+
 	if (m_pEditorWidget == NULL)
 		return;
 
